from chalk._gen.chalk.arrow.v1 import arrow_pb2 as _arrow_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class ScalarFunction(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SCALAR_FUNCTION_UNSPECIFIED: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ABS: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ACOS: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ASIN: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ATAN: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ASCII: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_CEIL: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_COS: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_DIGEST: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_EXP: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_FLOOR: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_LN: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_LOG: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_LOG10: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_LOG2: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ROUND: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_SIGNUM: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_SIN: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_SQRT: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_TAN: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_TRUNC: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_REGEXP_MATCH: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_BIT_LENGTH: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_BTRIM: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_CHARACTER_LENGTH: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_CHR: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_CONCAT: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_CONCAT_WITH_SEPARATOR: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_DATE_PART: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_DATE_TRUNC: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_INIT_CAP: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_LEFT: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_LPAD: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_LOWER: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_LTRIM: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_MD5: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_NULL_IF: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_OCTET_LENGTH: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_RANDOM: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_REGEXP_REPLACE: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_REPEAT: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_REPLACE: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_REVERSE: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_RIGHT: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_RPAD: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_RTRIM: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_SHA224: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_SHA256: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_SHA384: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_SHA512: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_SPLIT_PART: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_STARTS_WITH: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_STRPOS: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_SUBSTR: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_TO_HEX: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_TO_TIMESTAMP: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_TO_TIMESTAMP_MILLIS: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_TO_TIMESTAMP_MICROS: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_TO_TIMESTAMP_SECONDS: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_NOW: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_TRANSLATE: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_TRIM: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_UPPER: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_COALESCE: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_POWER: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_STRUCT_FUN: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_FROM_UNIXTIME: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ATAN2: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_DATE_BIN: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARROW_TYPEOF: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_CURRENT_DATE: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_CURRENT_TIME: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_UUID: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_CBRT: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ACOSH: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ASINH: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ATANH: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_SINH: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_COSH: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_TANH: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_PI: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_DEGREES: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_RADIANS: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_FACTORIAL: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_LCM: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_GCD: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_APPEND: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_CONCAT: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_DIMS: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_REPEAT: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_LENGTH: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_NDIMS: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_POSITION: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_POSITIONS: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_PREPEND: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_REMOVE: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_REPLACE: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_TO_STRING: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_CARDINALITY: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_ELEMENT: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_SLICE: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ENCODE: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_DECODE: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_COT: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_HAS: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_HAS_ANY: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_HAS_ALL: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_REMOVE_N: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_REPLACE_N: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_REMOVE_ALL: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_REPLACE_ALL: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_NANVL: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_FLATTEN: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ISNAN: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ISZERO: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_EMPTY: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_POP_BACK: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_STRING_TO_ARRAY: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_TO_TIMESTAMP_NANOS: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_INTERSECT: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_UNION: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_OVER_LAY: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_RANGE: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_EXCEPT: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_POP_FRONT: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_LEVENSHTEIN: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_SUBSTR_INDEX: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_FIND_IN_SET: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_SORT: _ClassVar[ScalarFunction]
    SCALAR_FUNCTION_ARRAY_DISTINCT: _ClassVar[ScalarFunction]

class AggregateFunction(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    AGGREGATE_FUNCTION_UNSPECIFIED: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_MIN: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_MAX: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_SUM: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_AVG: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_COUNT: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_APPROX_DISTINCT: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_ARRAY: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_VARIANCE: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_VARIANCE_POP: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_COVARIANCE: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_COVARIANCE_POP: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_STDDEV: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_STDDEV_POP: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_CORRELATION: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_APPROX_PERCENTILE_CONT: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_APPROX_MEDIAN: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_APPROX_PERCENTILE_CONT_WITH_WEIGHT: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_GROUPING: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_MEDIAN: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_BIT_AND: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_BIT_OR: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_BIT_XOR: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_BOOL_AND: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_BOOL_OR: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_FIRST_VALUE: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_LAST_VALUE: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_REGR_SLOPE: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_REGR_INTERCEPT: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_REGR_COUNT: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_REGR_R2: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_REGR_AVGX: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_REGR_AVGY: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_REGR_SXX: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_REGR_SYY: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_REGR_SXY: _ClassVar[AggregateFunction]
    AGGREGATE_FUNCTION_STRING: _ClassVar[AggregateFunction]

class BuiltInWindowFunction(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    BUILT_IN_WINDOW_FUNCTION_UNSPECIFIED: _ClassVar[BuiltInWindowFunction]
    BUILT_IN_WINDOW_FUNCTION_ROW_NUMBER: _ClassVar[BuiltInWindowFunction]
    BUILT_IN_WINDOW_FUNCTION_RANK: _ClassVar[BuiltInWindowFunction]
    BUILT_IN_WINDOW_FUNCTION_DENSE_RANK: _ClassVar[BuiltInWindowFunction]
    BUILT_IN_WINDOW_FUNCTION_PERCENT_RANK: _ClassVar[BuiltInWindowFunction]
    BUILT_IN_WINDOW_FUNCTION_CUME_DIST: _ClassVar[BuiltInWindowFunction]
    BUILT_IN_WINDOW_FUNCTION_NTILE: _ClassVar[BuiltInWindowFunction]
    BUILT_IN_WINDOW_FUNCTION_LAG: _ClassVar[BuiltInWindowFunction]
    BUILT_IN_WINDOW_FUNCTION_LEAD: _ClassVar[BuiltInWindowFunction]
    BUILT_IN_WINDOW_FUNCTION_FIRST_VALUE: _ClassVar[BuiltInWindowFunction]
    BUILT_IN_WINDOW_FUNCTION_LAST_VALUE: _ClassVar[BuiltInWindowFunction]
    BUILT_IN_WINDOW_FUNCTION_NTH_VALUE: _ClassVar[BuiltInWindowFunction]

class WindowFrameUnits(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    WINDOW_FRAME_UNITS_UNSPECIFIED: _ClassVar[WindowFrameUnits]
    WINDOW_FRAME_UNITS_ROWS: _ClassVar[WindowFrameUnits]
    WINDOW_FRAME_UNITS_RANGE: _ClassVar[WindowFrameUnits]
    WINDOW_FRAME_UNITS_GROUPS: _ClassVar[WindowFrameUnits]

class WindowFrameBoundType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    WINDOW_FRAME_BOUND_TYPE_UNSPECIFIED: _ClassVar[WindowFrameBoundType]
    WINDOW_FRAME_BOUND_TYPE_CURRENT_ROW: _ClassVar[WindowFrameBoundType]
    WINDOW_FRAME_BOUND_TYPE_PRECEDING: _ClassVar[WindowFrameBoundType]
    WINDOW_FRAME_BOUND_TYPE_FOLLOWING: _ClassVar[WindowFrameBoundType]

SCALAR_FUNCTION_UNSPECIFIED: ScalarFunction
SCALAR_FUNCTION_ABS: ScalarFunction
SCALAR_FUNCTION_ACOS: ScalarFunction
SCALAR_FUNCTION_ASIN: ScalarFunction
SCALAR_FUNCTION_ATAN: ScalarFunction
SCALAR_FUNCTION_ASCII: ScalarFunction
SCALAR_FUNCTION_CEIL: ScalarFunction
SCALAR_FUNCTION_COS: ScalarFunction
SCALAR_FUNCTION_DIGEST: ScalarFunction
SCALAR_FUNCTION_EXP: ScalarFunction
SCALAR_FUNCTION_FLOOR: ScalarFunction
SCALAR_FUNCTION_LN: ScalarFunction
SCALAR_FUNCTION_LOG: ScalarFunction
SCALAR_FUNCTION_LOG10: ScalarFunction
SCALAR_FUNCTION_LOG2: ScalarFunction
SCALAR_FUNCTION_ROUND: ScalarFunction
SCALAR_FUNCTION_SIGNUM: ScalarFunction
SCALAR_FUNCTION_SIN: ScalarFunction
SCALAR_FUNCTION_SQRT: ScalarFunction
SCALAR_FUNCTION_TAN: ScalarFunction
SCALAR_FUNCTION_TRUNC: ScalarFunction
SCALAR_FUNCTION_ARRAY: ScalarFunction
SCALAR_FUNCTION_REGEXP_MATCH: ScalarFunction
SCALAR_FUNCTION_BIT_LENGTH: ScalarFunction
SCALAR_FUNCTION_BTRIM: ScalarFunction
SCALAR_FUNCTION_CHARACTER_LENGTH: ScalarFunction
SCALAR_FUNCTION_CHR: ScalarFunction
SCALAR_FUNCTION_CONCAT: ScalarFunction
SCALAR_FUNCTION_CONCAT_WITH_SEPARATOR: ScalarFunction
SCALAR_FUNCTION_DATE_PART: ScalarFunction
SCALAR_FUNCTION_DATE_TRUNC: ScalarFunction
SCALAR_FUNCTION_INIT_CAP: ScalarFunction
SCALAR_FUNCTION_LEFT: ScalarFunction
SCALAR_FUNCTION_LPAD: ScalarFunction
SCALAR_FUNCTION_LOWER: ScalarFunction
SCALAR_FUNCTION_LTRIM: ScalarFunction
SCALAR_FUNCTION_MD5: ScalarFunction
SCALAR_FUNCTION_NULL_IF: ScalarFunction
SCALAR_FUNCTION_OCTET_LENGTH: ScalarFunction
SCALAR_FUNCTION_RANDOM: ScalarFunction
SCALAR_FUNCTION_REGEXP_REPLACE: ScalarFunction
SCALAR_FUNCTION_REPEAT: ScalarFunction
SCALAR_FUNCTION_REPLACE: ScalarFunction
SCALAR_FUNCTION_REVERSE: ScalarFunction
SCALAR_FUNCTION_RIGHT: ScalarFunction
SCALAR_FUNCTION_RPAD: ScalarFunction
SCALAR_FUNCTION_RTRIM: ScalarFunction
SCALAR_FUNCTION_SHA224: ScalarFunction
SCALAR_FUNCTION_SHA256: ScalarFunction
SCALAR_FUNCTION_SHA384: ScalarFunction
SCALAR_FUNCTION_SHA512: ScalarFunction
SCALAR_FUNCTION_SPLIT_PART: ScalarFunction
SCALAR_FUNCTION_STARTS_WITH: ScalarFunction
SCALAR_FUNCTION_STRPOS: ScalarFunction
SCALAR_FUNCTION_SUBSTR: ScalarFunction
SCALAR_FUNCTION_TO_HEX: ScalarFunction
SCALAR_FUNCTION_TO_TIMESTAMP: ScalarFunction
SCALAR_FUNCTION_TO_TIMESTAMP_MILLIS: ScalarFunction
SCALAR_FUNCTION_TO_TIMESTAMP_MICROS: ScalarFunction
SCALAR_FUNCTION_TO_TIMESTAMP_SECONDS: ScalarFunction
SCALAR_FUNCTION_NOW: ScalarFunction
SCALAR_FUNCTION_TRANSLATE: ScalarFunction
SCALAR_FUNCTION_TRIM: ScalarFunction
SCALAR_FUNCTION_UPPER: ScalarFunction
SCALAR_FUNCTION_COALESCE: ScalarFunction
SCALAR_FUNCTION_POWER: ScalarFunction
SCALAR_FUNCTION_STRUCT_FUN: ScalarFunction
SCALAR_FUNCTION_FROM_UNIXTIME: ScalarFunction
SCALAR_FUNCTION_ATAN2: ScalarFunction
SCALAR_FUNCTION_DATE_BIN: ScalarFunction
SCALAR_FUNCTION_ARROW_TYPEOF: ScalarFunction
SCALAR_FUNCTION_CURRENT_DATE: ScalarFunction
SCALAR_FUNCTION_CURRENT_TIME: ScalarFunction
SCALAR_FUNCTION_UUID: ScalarFunction
SCALAR_FUNCTION_CBRT: ScalarFunction
SCALAR_FUNCTION_ACOSH: ScalarFunction
SCALAR_FUNCTION_ASINH: ScalarFunction
SCALAR_FUNCTION_ATANH: ScalarFunction
SCALAR_FUNCTION_SINH: ScalarFunction
SCALAR_FUNCTION_COSH: ScalarFunction
SCALAR_FUNCTION_TANH: ScalarFunction
SCALAR_FUNCTION_PI: ScalarFunction
SCALAR_FUNCTION_DEGREES: ScalarFunction
SCALAR_FUNCTION_RADIANS: ScalarFunction
SCALAR_FUNCTION_FACTORIAL: ScalarFunction
SCALAR_FUNCTION_LCM: ScalarFunction
SCALAR_FUNCTION_GCD: ScalarFunction
SCALAR_FUNCTION_ARRAY_APPEND: ScalarFunction
SCALAR_FUNCTION_ARRAY_CONCAT: ScalarFunction
SCALAR_FUNCTION_ARRAY_DIMS: ScalarFunction
SCALAR_FUNCTION_ARRAY_REPEAT: ScalarFunction
SCALAR_FUNCTION_ARRAY_LENGTH: ScalarFunction
SCALAR_FUNCTION_ARRAY_NDIMS: ScalarFunction
SCALAR_FUNCTION_ARRAY_POSITION: ScalarFunction
SCALAR_FUNCTION_ARRAY_POSITIONS: ScalarFunction
SCALAR_FUNCTION_ARRAY_PREPEND: ScalarFunction
SCALAR_FUNCTION_ARRAY_REMOVE: ScalarFunction
SCALAR_FUNCTION_ARRAY_REPLACE: ScalarFunction
SCALAR_FUNCTION_ARRAY_TO_STRING: ScalarFunction
SCALAR_FUNCTION_CARDINALITY: ScalarFunction
SCALAR_FUNCTION_ARRAY_ELEMENT: ScalarFunction
SCALAR_FUNCTION_ARRAY_SLICE: ScalarFunction
SCALAR_FUNCTION_ENCODE: ScalarFunction
SCALAR_FUNCTION_DECODE: ScalarFunction
SCALAR_FUNCTION_COT: ScalarFunction
SCALAR_FUNCTION_ARRAY_HAS: ScalarFunction
SCALAR_FUNCTION_ARRAY_HAS_ANY: ScalarFunction
SCALAR_FUNCTION_ARRAY_HAS_ALL: ScalarFunction
SCALAR_FUNCTION_ARRAY_REMOVE_N: ScalarFunction
SCALAR_FUNCTION_ARRAY_REPLACE_N: ScalarFunction
SCALAR_FUNCTION_ARRAY_REMOVE_ALL: ScalarFunction
SCALAR_FUNCTION_ARRAY_REPLACE_ALL: ScalarFunction
SCALAR_FUNCTION_NANVL: ScalarFunction
SCALAR_FUNCTION_FLATTEN: ScalarFunction
SCALAR_FUNCTION_ISNAN: ScalarFunction
SCALAR_FUNCTION_ISZERO: ScalarFunction
SCALAR_FUNCTION_ARRAY_EMPTY: ScalarFunction
SCALAR_FUNCTION_ARRAY_POP_BACK: ScalarFunction
SCALAR_FUNCTION_STRING_TO_ARRAY: ScalarFunction
SCALAR_FUNCTION_TO_TIMESTAMP_NANOS: ScalarFunction
SCALAR_FUNCTION_ARRAY_INTERSECT: ScalarFunction
SCALAR_FUNCTION_ARRAY_UNION: ScalarFunction
SCALAR_FUNCTION_OVER_LAY: ScalarFunction
SCALAR_FUNCTION_RANGE: ScalarFunction
SCALAR_FUNCTION_ARRAY_EXCEPT: ScalarFunction
SCALAR_FUNCTION_ARRAY_POP_FRONT: ScalarFunction
SCALAR_FUNCTION_LEVENSHTEIN: ScalarFunction
SCALAR_FUNCTION_SUBSTR_INDEX: ScalarFunction
SCALAR_FUNCTION_FIND_IN_SET: ScalarFunction
SCALAR_FUNCTION_ARRAY_SORT: ScalarFunction
SCALAR_FUNCTION_ARRAY_DISTINCT: ScalarFunction
AGGREGATE_FUNCTION_UNSPECIFIED: AggregateFunction
AGGREGATE_FUNCTION_MIN: AggregateFunction
AGGREGATE_FUNCTION_MAX: AggregateFunction
AGGREGATE_FUNCTION_SUM: AggregateFunction
AGGREGATE_FUNCTION_AVG: AggregateFunction
AGGREGATE_FUNCTION_COUNT: AggregateFunction
AGGREGATE_FUNCTION_APPROX_DISTINCT: AggregateFunction
AGGREGATE_FUNCTION_ARRAY: AggregateFunction
AGGREGATE_FUNCTION_VARIANCE: AggregateFunction
AGGREGATE_FUNCTION_VARIANCE_POP: AggregateFunction
AGGREGATE_FUNCTION_COVARIANCE: AggregateFunction
AGGREGATE_FUNCTION_COVARIANCE_POP: AggregateFunction
AGGREGATE_FUNCTION_STDDEV: AggregateFunction
AGGREGATE_FUNCTION_STDDEV_POP: AggregateFunction
AGGREGATE_FUNCTION_CORRELATION: AggregateFunction
AGGREGATE_FUNCTION_APPROX_PERCENTILE_CONT: AggregateFunction
AGGREGATE_FUNCTION_APPROX_MEDIAN: AggregateFunction
AGGREGATE_FUNCTION_APPROX_PERCENTILE_CONT_WITH_WEIGHT: AggregateFunction
AGGREGATE_FUNCTION_GROUPING: AggregateFunction
AGGREGATE_FUNCTION_MEDIAN: AggregateFunction
AGGREGATE_FUNCTION_BIT_AND: AggregateFunction
AGGREGATE_FUNCTION_BIT_OR: AggregateFunction
AGGREGATE_FUNCTION_BIT_XOR: AggregateFunction
AGGREGATE_FUNCTION_BOOL_AND: AggregateFunction
AGGREGATE_FUNCTION_BOOL_OR: AggregateFunction
AGGREGATE_FUNCTION_FIRST_VALUE: AggregateFunction
AGGREGATE_FUNCTION_LAST_VALUE: AggregateFunction
AGGREGATE_FUNCTION_REGR_SLOPE: AggregateFunction
AGGREGATE_FUNCTION_REGR_INTERCEPT: AggregateFunction
AGGREGATE_FUNCTION_REGR_COUNT: AggregateFunction
AGGREGATE_FUNCTION_REGR_R2: AggregateFunction
AGGREGATE_FUNCTION_REGR_AVGX: AggregateFunction
AGGREGATE_FUNCTION_REGR_AVGY: AggregateFunction
AGGREGATE_FUNCTION_REGR_SXX: AggregateFunction
AGGREGATE_FUNCTION_REGR_SYY: AggregateFunction
AGGREGATE_FUNCTION_REGR_SXY: AggregateFunction
AGGREGATE_FUNCTION_STRING: AggregateFunction
BUILT_IN_WINDOW_FUNCTION_UNSPECIFIED: BuiltInWindowFunction
BUILT_IN_WINDOW_FUNCTION_ROW_NUMBER: BuiltInWindowFunction
BUILT_IN_WINDOW_FUNCTION_RANK: BuiltInWindowFunction
BUILT_IN_WINDOW_FUNCTION_DENSE_RANK: BuiltInWindowFunction
BUILT_IN_WINDOW_FUNCTION_PERCENT_RANK: BuiltInWindowFunction
BUILT_IN_WINDOW_FUNCTION_CUME_DIST: BuiltInWindowFunction
BUILT_IN_WINDOW_FUNCTION_NTILE: BuiltInWindowFunction
BUILT_IN_WINDOW_FUNCTION_LAG: BuiltInWindowFunction
BUILT_IN_WINDOW_FUNCTION_LEAD: BuiltInWindowFunction
BUILT_IN_WINDOW_FUNCTION_FIRST_VALUE: BuiltInWindowFunction
BUILT_IN_WINDOW_FUNCTION_LAST_VALUE: BuiltInWindowFunction
BUILT_IN_WINDOW_FUNCTION_NTH_VALUE: BuiltInWindowFunction
WINDOW_FRAME_UNITS_UNSPECIFIED: WindowFrameUnits
WINDOW_FRAME_UNITS_ROWS: WindowFrameUnits
WINDOW_FRAME_UNITS_RANGE: WindowFrameUnits
WINDOW_FRAME_UNITS_GROUPS: WindowFrameUnits
WINDOW_FRAME_BOUND_TYPE_UNSPECIFIED: WindowFrameBoundType
WINDOW_FRAME_BOUND_TYPE_CURRENT_ROW: WindowFrameBoundType
WINDOW_FRAME_BOUND_TYPE_PRECEDING: WindowFrameBoundType
WINDOW_FRAME_BOUND_TYPE_FOLLOWING: WindowFrameBoundType

class Identifier(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ExprGetAttribute(_message.Message):
    __slots__ = ("parent", "attribute")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    parent: LogicalExprNode
    attribute: Identifier
    def __init__(
        self,
        parent: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        attribute: _Optional[_Union[Identifier, _Mapping]] = ...,
    ) -> None: ...

class ExprGetSubscript(_message.Message):
    __slots__ = ("parent", "subscript")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    SUBSCRIPT_FIELD_NUMBER: _ClassVar[int]
    parent: LogicalExprNode
    subscript: _containers.RepeatedCompositeFieldContainer[LogicalExprNode]
    def __init__(
        self,
        parent: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        subscript: _Optional[_Iterable[_Union[LogicalExprNode, _Mapping]]] = ...,
    ) -> None: ...

class ExprCall(_message.Message):
    __slots__ = ("func", "args", "kwargs")
    class KwargsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: LogicalExprNode
        def __init__(
            self, key: _Optional[str] = ..., value: _Optional[_Union[LogicalExprNode, _Mapping]] = ...
        ) -> None: ...

    FUNC_FIELD_NUMBER: _ClassVar[int]
    ARGS_FIELD_NUMBER: _ClassVar[int]
    KWARGS_FIELD_NUMBER: _ClassVar[int]
    func: LogicalExprNode
    args: _containers.RepeatedCompositeFieldContainer[LogicalExprNode]
    kwargs: _containers.MessageMap[str, LogicalExprNode]
    def __init__(
        self,
        func: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        args: _Optional[_Iterable[_Union[LogicalExprNode, _Mapping]]] = ...,
        kwargs: _Optional[_Mapping[str, LogicalExprNode]] = ...,
    ) -> None: ...

class ExprLiteral(_message.Message):
    __slots__ = ("value", "is_arrow_scalar_object")
    VALUE_FIELD_NUMBER: _ClassVar[int]
    IS_ARROW_SCALAR_OBJECT_FIELD_NUMBER: _ClassVar[int]
    value: _arrow_pb2.ScalarValue
    is_arrow_scalar_object: bool
    def __init__(
        self, value: _Optional[_Union[_arrow_pb2.ScalarValue, _Mapping]] = ..., is_arrow_scalar_object: bool = ...
    ) -> None: ...

class LogicalExprNode(_message.Message):
    __slots__ = (
        "identifier",
        "get_attribute",
        "get_subscript",
        "call",
        "literal_value",
        "expr_id",
        "column",
        "alias",
        "literal",
        "binary_expr",
        "aggregate_expr",
        "is_null_expr",
        "is_not_null_expr",
        "not_expr",
        "between",
        "case",
        "cast",
        "sort",
        "negative",
        "in_list",
        "wildcard",
        "scalar_function",
        "try_cast",
        "window_expr",
        "aggregate_udf_expr",
        "scalar_udf_expr",
        "get_indexed_field",
        "grouping_set",
        "cube",
        "rollup",
        "is_true",
        "is_false",
        "is_unknown",
        "is_not_true",
        "is_not_false",
        "is_not_unknown",
        "like",
        "ilike",
        "similar_to",
        "placeholder",
    )
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    GET_ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    GET_SUBSCRIPT_FIELD_NUMBER: _ClassVar[int]
    CALL_FIELD_NUMBER: _ClassVar[int]
    LITERAL_VALUE_FIELD_NUMBER: _ClassVar[int]
    EXPR_ID_FIELD_NUMBER: _ClassVar[int]
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    ALIAS_FIELD_NUMBER: _ClassVar[int]
    LITERAL_FIELD_NUMBER: _ClassVar[int]
    BINARY_EXPR_FIELD_NUMBER: _ClassVar[int]
    AGGREGATE_EXPR_FIELD_NUMBER: _ClassVar[int]
    IS_NULL_EXPR_FIELD_NUMBER: _ClassVar[int]
    IS_NOT_NULL_EXPR_FIELD_NUMBER: _ClassVar[int]
    NOT_EXPR_FIELD_NUMBER: _ClassVar[int]
    BETWEEN_FIELD_NUMBER: _ClassVar[int]
    CASE_FIELD_NUMBER: _ClassVar[int]
    CAST_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    NEGATIVE_FIELD_NUMBER: _ClassVar[int]
    IN_LIST_FIELD_NUMBER: _ClassVar[int]
    WILDCARD_FIELD_NUMBER: _ClassVar[int]
    SCALAR_FUNCTION_FIELD_NUMBER: _ClassVar[int]
    TRY_CAST_FIELD_NUMBER: _ClassVar[int]
    WINDOW_EXPR_FIELD_NUMBER: _ClassVar[int]
    AGGREGATE_UDF_EXPR_FIELD_NUMBER: _ClassVar[int]
    SCALAR_UDF_EXPR_FIELD_NUMBER: _ClassVar[int]
    GET_INDEXED_FIELD_FIELD_NUMBER: _ClassVar[int]
    GROUPING_SET_FIELD_NUMBER: _ClassVar[int]
    CUBE_FIELD_NUMBER: _ClassVar[int]
    ROLLUP_FIELD_NUMBER: _ClassVar[int]
    IS_TRUE_FIELD_NUMBER: _ClassVar[int]
    IS_FALSE_FIELD_NUMBER: _ClassVar[int]
    IS_UNKNOWN_FIELD_NUMBER: _ClassVar[int]
    IS_NOT_TRUE_FIELD_NUMBER: _ClassVar[int]
    IS_NOT_FALSE_FIELD_NUMBER: _ClassVar[int]
    IS_NOT_UNKNOWN_FIELD_NUMBER: _ClassVar[int]
    LIKE_FIELD_NUMBER: _ClassVar[int]
    ILIKE_FIELD_NUMBER: _ClassVar[int]
    SIMILAR_TO_FIELD_NUMBER: _ClassVar[int]
    PLACEHOLDER_FIELD_NUMBER: _ClassVar[int]
    identifier: Identifier
    get_attribute: ExprGetAttribute
    get_subscript: ExprGetSubscript
    call: ExprCall
    literal_value: ExprLiteral
    expr_id: str
    column: Column
    alias: AliasNode
    literal: _arrow_pb2.ScalarValue
    binary_expr: BinaryExprNode
    aggregate_expr: AggregateExprNode
    is_null_expr: IsNull
    is_not_null_expr: IsNotNull
    not_expr: Not
    between: BetweenNode
    case: CaseNode
    cast: CastNode
    sort: SortExprNode
    negative: NegativeNode
    in_list: InListNode
    wildcard: Wildcard
    scalar_function: ScalarFunctionNode
    try_cast: TryCastNode
    window_expr: WindowExprNode
    aggregate_udf_expr: AggregateUDFExprNode
    scalar_udf_expr: ScalarUDFExprNode
    get_indexed_field: GetIndexedField
    grouping_set: GroupingSetNode
    cube: CubeNode
    rollup: RollupNode
    is_true: IsTrue
    is_false: IsFalse
    is_unknown: IsUnknown
    is_not_true: IsNotTrue
    is_not_false: IsNotFalse
    is_not_unknown: IsNotUnknown
    like: LikeNode
    ilike: ILikeNode
    similar_to: SimilarToNode
    placeholder: PlaceholderNode
    def __init__(
        self,
        identifier: _Optional[_Union[Identifier, _Mapping]] = ...,
        get_attribute: _Optional[_Union[ExprGetAttribute, _Mapping]] = ...,
        get_subscript: _Optional[_Union[ExprGetSubscript, _Mapping]] = ...,
        call: _Optional[_Union[ExprCall, _Mapping]] = ...,
        literal_value: _Optional[_Union[ExprLiteral, _Mapping]] = ...,
        expr_id: _Optional[str] = ...,
        column: _Optional[_Union[Column, _Mapping]] = ...,
        alias: _Optional[_Union[AliasNode, _Mapping]] = ...,
        literal: _Optional[_Union[_arrow_pb2.ScalarValue, _Mapping]] = ...,
        binary_expr: _Optional[_Union[BinaryExprNode, _Mapping]] = ...,
        aggregate_expr: _Optional[_Union[AggregateExprNode, _Mapping]] = ...,
        is_null_expr: _Optional[_Union[IsNull, _Mapping]] = ...,
        is_not_null_expr: _Optional[_Union[IsNotNull, _Mapping]] = ...,
        not_expr: _Optional[_Union[Not, _Mapping]] = ...,
        between: _Optional[_Union[BetweenNode, _Mapping]] = ...,
        case: _Optional[_Union[CaseNode, _Mapping]] = ...,
        cast: _Optional[_Union[CastNode, _Mapping]] = ...,
        sort: _Optional[_Union[SortExprNode, _Mapping]] = ...,
        negative: _Optional[_Union[NegativeNode, _Mapping]] = ...,
        in_list: _Optional[_Union[InListNode, _Mapping]] = ...,
        wildcard: _Optional[_Union[Wildcard, _Mapping]] = ...,
        scalar_function: _Optional[_Union[ScalarFunctionNode, _Mapping]] = ...,
        try_cast: _Optional[_Union[TryCastNode, _Mapping]] = ...,
        window_expr: _Optional[_Union[WindowExprNode, _Mapping]] = ...,
        aggregate_udf_expr: _Optional[_Union[AggregateUDFExprNode, _Mapping]] = ...,
        scalar_udf_expr: _Optional[_Union[ScalarUDFExprNode, _Mapping]] = ...,
        get_indexed_field: _Optional[_Union[GetIndexedField, _Mapping]] = ...,
        grouping_set: _Optional[_Union[GroupingSetNode, _Mapping]] = ...,
        cube: _Optional[_Union[CubeNode, _Mapping]] = ...,
        rollup: _Optional[_Union[RollupNode, _Mapping]] = ...,
        is_true: _Optional[_Union[IsTrue, _Mapping]] = ...,
        is_false: _Optional[_Union[IsFalse, _Mapping]] = ...,
        is_unknown: _Optional[_Union[IsUnknown, _Mapping]] = ...,
        is_not_true: _Optional[_Union[IsNotTrue, _Mapping]] = ...,
        is_not_false: _Optional[_Union[IsNotFalse, _Mapping]] = ...,
        is_not_unknown: _Optional[_Union[IsNotUnknown, _Mapping]] = ...,
        like: _Optional[_Union[LikeNode, _Mapping]] = ...,
        ilike: _Optional[_Union[ILikeNode, _Mapping]] = ...,
        similar_to: _Optional[_Union[SimilarToNode, _Mapping]] = ...,
        placeholder: _Optional[_Union[PlaceholderNode, _Mapping]] = ...,
    ) -> None: ...

class ColumnRelation(_message.Message):
    __slots__ = ("relation",)
    RELATION_FIELD_NUMBER: _ClassVar[int]
    relation: str
    def __init__(self, relation: _Optional[str] = ...) -> None: ...

class Column(_message.Message):
    __slots__ = ("name", "relation")
    NAME_FIELD_NUMBER: _ClassVar[int]
    RELATION_FIELD_NUMBER: _ClassVar[int]
    name: str
    relation: ColumnRelation
    def __init__(
        self, name: _Optional[str] = ..., relation: _Optional[_Union[ColumnRelation, _Mapping]] = ...
    ) -> None: ...

class Wildcard(_message.Message):
    __slots__ = ("qualifier",)
    QUALIFIER_FIELD_NUMBER: _ClassVar[int]
    qualifier: str
    def __init__(self, qualifier: _Optional[str] = ...) -> None: ...

class PlaceholderNode(_message.Message):
    __slots__ = ("id", "data_type")
    ID_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    id: str
    data_type: _arrow_pb2.ArrowType
    def __init__(
        self, id: _Optional[str] = ..., data_type: _Optional[_Union[_arrow_pb2.ArrowType, _Mapping]] = ...
    ) -> None: ...

class LogicalExprList(_message.Message):
    __slots__ = ("expr",)
    EXPR_FIELD_NUMBER: _ClassVar[int]
    expr: _containers.RepeatedCompositeFieldContainer[LogicalExprNode]
    def __init__(self, expr: _Optional[_Iterable[_Union[LogicalExprNode, _Mapping]]] = ...) -> None: ...

class GroupingSetNode(_message.Message):
    __slots__ = ("expr",)
    EXPR_FIELD_NUMBER: _ClassVar[int]
    expr: _containers.RepeatedCompositeFieldContainer[LogicalExprList]
    def __init__(self, expr: _Optional[_Iterable[_Union[LogicalExprList, _Mapping]]] = ...) -> None: ...

class CubeNode(_message.Message):
    __slots__ = ("expr",)
    EXPR_FIELD_NUMBER: _ClassVar[int]
    expr: _containers.RepeatedCompositeFieldContainer[LogicalExprNode]
    def __init__(self, expr: _Optional[_Iterable[_Union[LogicalExprNode, _Mapping]]] = ...) -> None: ...

class RollupNode(_message.Message):
    __slots__ = ("expr",)
    EXPR_FIELD_NUMBER: _ClassVar[int]
    expr: _containers.RepeatedCompositeFieldContainer[LogicalExprNode]
    def __init__(self, expr: _Optional[_Iterable[_Union[LogicalExprNode, _Mapping]]] = ...) -> None: ...

class NamedStructField(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: _arrow_pb2.ScalarValue
    def __init__(self, name: _Optional[_Union[_arrow_pb2.ScalarValue, _Mapping]] = ...) -> None: ...

class ListIndex(_message.Message):
    __slots__ = ("key",)
    KEY_FIELD_NUMBER: _ClassVar[int]
    key: LogicalExprNode
    def __init__(self, key: _Optional[_Union[LogicalExprNode, _Mapping]] = ...) -> None: ...

class ListRange(_message.Message):
    __slots__ = ("start", "stop")
    START_FIELD_NUMBER: _ClassVar[int]
    STOP_FIELD_NUMBER: _ClassVar[int]
    start: LogicalExprNode
    stop: LogicalExprNode
    def __init__(
        self,
        start: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        stop: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
    ) -> None: ...

class GetIndexedField(_message.Message):
    __slots__ = ("expr", "named_struct_field", "list_index", "list_range")
    EXPR_FIELD_NUMBER: _ClassVar[int]
    NAMED_STRUCT_FIELD_FIELD_NUMBER: _ClassVar[int]
    LIST_INDEX_FIELD_NUMBER: _ClassVar[int]
    LIST_RANGE_FIELD_NUMBER: _ClassVar[int]
    expr: LogicalExprNode
    named_struct_field: NamedStructField
    list_index: ListIndex
    list_range: ListRange
    def __init__(
        self,
        expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        named_struct_field: _Optional[_Union[NamedStructField, _Mapping]] = ...,
        list_index: _Optional[_Union[ListIndex, _Mapping]] = ...,
        list_range: _Optional[_Union[ListRange, _Mapping]] = ...,
    ) -> None: ...

class IsNull(_message.Message):
    __slots__ = ("expr",)
    EXPR_FIELD_NUMBER: _ClassVar[int]
    expr: LogicalExprNode
    def __init__(self, expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...) -> None: ...

class IsNotNull(_message.Message):
    __slots__ = ("expr",)
    EXPR_FIELD_NUMBER: _ClassVar[int]
    expr: LogicalExprNode
    def __init__(self, expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...) -> None: ...

class IsTrue(_message.Message):
    __slots__ = ("expr",)
    EXPR_FIELD_NUMBER: _ClassVar[int]
    expr: LogicalExprNode
    def __init__(self, expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...) -> None: ...

class IsFalse(_message.Message):
    __slots__ = ("expr",)
    EXPR_FIELD_NUMBER: _ClassVar[int]
    expr: LogicalExprNode
    def __init__(self, expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...) -> None: ...

class IsUnknown(_message.Message):
    __slots__ = ("expr",)
    EXPR_FIELD_NUMBER: _ClassVar[int]
    expr: LogicalExprNode
    def __init__(self, expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...) -> None: ...

class IsNotTrue(_message.Message):
    __slots__ = ("expr",)
    EXPR_FIELD_NUMBER: _ClassVar[int]
    expr: LogicalExprNode
    def __init__(self, expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...) -> None: ...

class IsNotFalse(_message.Message):
    __slots__ = ("expr",)
    EXPR_FIELD_NUMBER: _ClassVar[int]
    expr: LogicalExprNode
    def __init__(self, expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...) -> None: ...

class IsNotUnknown(_message.Message):
    __slots__ = ("expr",)
    EXPR_FIELD_NUMBER: _ClassVar[int]
    expr: LogicalExprNode
    def __init__(self, expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...) -> None: ...

class Not(_message.Message):
    __slots__ = ("expr",)
    EXPR_FIELD_NUMBER: _ClassVar[int]
    expr: LogicalExprNode
    def __init__(self, expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...) -> None: ...

class AliasNode(_message.Message):
    __slots__ = ("expr", "alias", "relation")
    EXPR_FIELD_NUMBER: _ClassVar[int]
    ALIAS_FIELD_NUMBER: _ClassVar[int]
    RELATION_FIELD_NUMBER: _ClassVar[int]
    expr: LogicalExprNode
    alias: str
    relation: _containers.RepeatedCompositeFieldContainer[OwnedTableReference]
    def __init__(
        self,
        expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        alias: _Optional[str] = ...,
        relation: _Optional[_Iterable[_Union[OwnedTableReference, _Mapping]]] = ...,
    ) -> None: ...

class BareTableReference(_message.Message):
    __slots__ = ("table",)
    TABLE_FIELD_NUMBER: _ClassVar[int]
    table: str
    def __init__(self, table: _Optional[str] = ...) -> None: ...

class PartialTableReference(_message.Message):
    __slots__ = ("schema", "table")
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    TABLE_FIELD_NUMBER: _ClassVar[int]
    schema: str
    table: str
    def __init__(self, schema: _Optional[str] = ..., table: _Optional[str] = ...) -> None: ...

class FullTableReference(_message.Message):
    __slots__ = ("catalog", "schema", "table")
    CATALOG_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    TABLE_FIELD_NUMBER: _ClassVar[int]
    catalog: str
    schema: str
    table: str
    def __init__(
        self, catalog: _Optional[str] = ..., schema: _Optional[str] = ..., table: _Optional[str] = ...
    ) -> None: ...

class OwnedTableReference(_message.Message):
    __slots__ = ("bare", "partial", "full")
    BARE_FIELD_NUMBER: _ClassVar[int]
    PARTIAL_FIELD_NUMBER: _ClassVar[int]
    FULL_FIELD_NUMBER: _ClassVar[int]
    bare: BareTableReference
    partial: PartialTableReference
    full: FullTableReference
    def __init__(
        self,
        bare: _Optional[_Union[BareTableReference, _Mapping]] = ...,
        partial: _Optional[_Union[PartialTableReference, _Mapping]] = ...,
        full: _Optional[_Union[FullTableReference, _Mapping]] = ...,
    ) -> None: ...

class BinaryExprNode(_message.Message):
    __slots__ = ("operands", "op")
    OPERANDS_FIELD_NUMBER: _ClassVar[int]
    OP_FIELD_NUMBER: _ClassVar[int]
    operands: _containers.RepeatedCompositeFieldContainer[LogicalExprNode]
    op: str
    def __init__(
        self, operands: _Optional[_Iterable[_Union[LogicalExprNode, _Mapping]]] = ..., op: _Optional[str] = ...
    ) -> None: ...

class NegativeNode(_message.Message):
    __slots__ = ("expr",)
    EXPR_FIELD_NUMBER: _ClassVar[int]
    expr: LogicalExprNode
    def __init__(self, expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...) -> None: ...

class InListNode(_message.Message):
    __slots__ = ("expr", "list", "negated")
    EXPR_FIELD_NUMBER: _ClassVar[int]
    LIST_FIELD_NUMBER: _ClassVar[int]
    NEGATED_FIELD_NUMBER: _ClassVar[int]
    expr: LogicalExprNode
    list: _containers.RepeatedCompositeFieldContainer[LogicalExprNode]
    negated: bool
    def __init__(
        self,
        expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        list: _Optional[_Iterable[_Union[LogicalExprNode, _Mapping]]] = ...,
        negated: bool = ...,
    ) -> None: ...

class ScalarFunctionNode(_message.Message):
    __slots__ = ("fun", "args")
    FUN_FIELD_NUMBER: _ClassVar[int]
    ARGS_FIELD_NUMBER: _ClassVar[int]
    fun: ScalarFunction
    args: _containers.RepeatedCompositeFieldContainer[LogicalExprNode]
    def __init__(
        self,
        fun: _Optional[_Union[ScalarFunction, str]] = ...,
        args: _Optional[_Iterable[_Union[LogicalExprNode, _Mapping]]] = ...,
    ) -> None: ...

class AggregateExprNode(_message.Message):
    __slots__ = ("aggr_function", "expr", "distinct", "filter", "order_by")
    AGGR_FUNCTION_FIELD_NUMBER: _ClassVar[int]
    EXPR_FIELD_NUMBER: _ClassVar[int]
    DISTINCT_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    aggr_function: AggregateFunction
    expr: _containers.RepeatedCompositeFieldContainer[LogicalExprNode]
    distinct: bool
    filter: LogicalExprNode
    order_by: _containers.RepeatedCompositeFieldContainer[LogicalExprNode]
    def __init__(
        self,
        aggr_function: _Optional[_Union[AggregateFunction, str]] = ...,
        expr: _Optional[_Iterable[_Union[LogicalExprNode, _Mapping]]] = ...,
        distinct: bool = ...,
        filter: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        order_by: _Optional[_Iterable[_Union[LogicalExprNode, _Mapping]]] = ...,
    ) -> None: ...

class AggregateUDFExprNode(_message.Message):
    __slots__ = ("fun_name", "args", "filter", "order_by", "kwargs")
    class KwargsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: LogicalExprNode
        def __init__(
            self, key: _Optional[str] = ..., value: _Optional[_Union[LogicalExprNode, _Mapping]] = ...
        ) -> None: ...

    FUN_NAME_FIELD_NUMBER: _ClassVar[int]
    ARGS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    KWARGS_FIELD_NUMBER: _ClassVar[int]
    fun_name: str
    args: _containers.RepeatedCompositeFieldContainer[LogicalExprNode]
    filter: LogicalExprNode
    order_by: _containers.RepeatedCompositeFieldContainer[LogicalExprNode]
    kwargs: _containers.MessageMap[str, LogicalExprNode]
    def __init__(
        self,
        fun_name: _Optional[str] = ...,
        args: _Optional[_Iterable[_Union[LogicalExprNode, _Mapping]]] = ...,
        filter: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        order_by: _Optional[_Iterable[_Union[LogicalExprNode, _Mapping]]] = ...,
        kwargs: _Optional[_Mapping[str, LogicalExprNode]] = ...,
    ) -> None: ...

class ScalarUDFExprNode(_message.Message):
    __slots__ = ("fun_name", "args")
    FUN_NAME_FIELD_NUMBER: _ClassVar[int]
    ARGS_FIELD_NUMBER: _ClassVar[int]
    fun_name: str
    args: _containers.RepeatedCompositeFieldContainer[LogicalExprNode]
    def __init__(
        self, fun_name: _Optional[str] = ..., args: _Optional[_Iterable[_Union[LogicalExprNode, _Mapping]]] = ...
    ) -> None: ...

class WindowExprNode(_message.Message):
    __slots__ = (
        "aggr_function",
        "built_in_function",
        "udaf",
        "udwf",
        "expr",
        "partition_by",
        "order_by",
        "window_frame",
    )
    AGGR_FUNCTION_FIELD_NUMBER: _ClassVar[int]
    BUILT_IN_FUNCTION_FIELD_NUMBER: _ClassVar[int]
    UDAF_FIELD_NUMBER: _ClassVar[int]
    UDWF_FIELD_NUMBER: _ClassVar[int]
    EXPR_FIELD_NUMBER: _ClassVar[int]
    PARTITION_BY_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    WINDOW_FRAME_FIELD_NUMBER: _ClassVar[int]
    aggr_function: AggregateFunction
    built_in_function: BuiltInWindowFunction
    udaf: str
    udwf: str
    expr: LogicalExprNode
    partition_by: _containers.RepeatedCompositeFieldContainer[LogicalExprNode]
    order_by: _containers.RepeatedCompositeFieldContainer[LogicalExprNode]
    window_frame: WindowFrame
    def __init__(
        self,
        aggr_function: _Optional[_Union[AggregateFunction, str]] = ...,
        built_in_function: _Optional[_Union[BuiltInWindowFunction, str]] = ...,
        udaf: _Optional[str] = ...,
        udwf: _Optional[str] = ...,
        expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        partition_by: _Optional[_Iterable[_Union[LogicalExprNode, _Mapping]]] = ...,
        order_by: _Optional[_Iterable[_Union[LogicalExprNode, _Mapping]]] = ...,
        window_frame: _Optional[_Union[WindowFrame, _Mapping]] = ...,
    ) -> None: ...

class BetweenNode(_message.Message):
    __slots__ = ("expr", "negated", "low", "high")
    EXPR_FIELD_NUMBER: _ClassVar[int]
    NEGATED_FIELD_NUMBER: _ClassVar[int]
    LOW_FIELD_NUMBER: _ClassVar[int]
    HIGH_FIELD_NUMBER: _ClassVar[int]
    expr: LogicalExprNode
    negated: bool
    low: LogicalExprNode
    high: LogicalExprNode
    def __init__(
        self,
        expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        negated: bool = ...,
        low: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        high: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
    ) -> None: ...

class LikeNode(_message.Message):
    __slots__ = ("negated", "expr", "pattern", "escape_char")
    NEGATED_FIELD_NUMBER: _ClassVar[int]
    EXPR_FIELD_NUMBER: _ClassVar[int]
    PATTERN_FIELD_NUMBER: _ClassVar[int]
    ESCAPE_CHAR_FIELD_NUMBER: _ClassVar[int]
    negated: bool
    expr: LogicalExprNode
    pattern: LogicalExprNode
    escape_char: str
    def __init__(
        self,
        negated: bool = ...,
        expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        pattern: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        escape_char: _Optional[str] = ...,
    ) -> None: ...

class ILikeNode(_message.Message):
    __slots__ = ("negated", "expr", "pattern", "escape_char")
    NEGATED_FIELD_NUMBER: _ClassVar[int]
    EXPR_FIELD_NUMBER: _ClassVar[int]
    PATTERN_FIELD_NUMBER: _ClassVar[int]
    ESCAPE_CHAR_FIELD_NUMBER: _ClassVar[int]
    negated: bool
    expr: LogicalExprNode
    pattern: LogicalExprNode
    escape_char: str
    def __init__(
        self,
        negated: bool = ...,
        expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        pattern: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        escape_char: _Optional[str] = ...,
    ) -> None: ...

class SimilarToNode(_message.Message):
    __slots__ = ("negated", "expr", "pattern", "escape_char")
    NEGATED_FIELD_NUMBER: _ClassVar[int]
    EXPR_FIELD_NUMBER: _ClassVar[int]
    PATTERN_FIELD_NUMBER: _ClassVar[int]
    ESCAPE_CHAR_FIELD_NUMBER: _ClassVar[int]
    negated: bool
    expr: LogicalExprNode
    pattern: LogicalExprNode
    escape_char: str
    def __init__(
        self,
        negated: bool = ...,
        expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        pattern: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        escape_char: _Optional[str] = ...,
    ) -> None: ...

class CaseNode(_message.Message):
    __slots__ = ("expr", "when_then_expr", "else_expr")
    EXPR_FIELD_NUMBER: _ClassVar[int]
    WHEN_THEN_EXPR_FIELD_NUMBER: _ClassVar[int]
    ELSE_EXPR_FIELD_NUMBER: _ClassVar[int]
    expr: LogicalExprNode
    when_then_expr: _containers.RepeatedCompositeFieldContainer[WhenThen]
    else_expr: LogicalExprNode
    def __init__(
        self,
        expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        when_then_expr: _Optional[_Iterable[_Union[WhenThen, _Mapping]]] = ...,
        else_expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
    ) -> None: ...

class WhenThen(_message.Message):
    __slots__ = ("when_expr", "then_expr")
    WHEN_EXPR_FIELD_NUMBER: _ClassVar[int]
    THEN_EXPR_FIELD_NUMBER: _ClassVar[int]
    when_expr: LogicalExprNode
    then_expr: LogicalExprNode
    def __init__(
        self,
        when_expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        then_expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
    ) -> None: ...

class CastNode(_message.Message):
    __slots__ = ("expr", "arrow_type")
    EXPR_FIELD_NUMBER: _ClassVar[int]
    ARROW_TYPE_FIELD_NUMBER: _ClassVar[int]
    expr: LogicalExprNode
    arrow_type: _arrow_pb2.ArrowType
    def __init__(
        self,
        expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        arrow_type: _Optional[_Union[_arrow_pb2.ArrowType, _Mapping]] = ...,
    ) -> None: ...

class TryCastNode(_message.Message):
    __slots__ = ("expr", "arrow_type")
    EXPR_FIELD_NUMBER: _ClassVar[int]
    ARROW_TYPE_FIELD_NUMBER: _ClassVar[int]
    expr: LogicalExprNode
    arrow_type: _arrow_pb2.ArrowType
    def __init__(
        self,
        expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ...,
        arrow_type: _Optional[_Union[_arrow_pb2.ArrowType, _Mapping]] = ...,
    ) -> None: ...

class SortExprNode(_message.Message):
    __slots__ = ("expr", "asc", "nulls_first")
    EXPR_FIELD_NUMBER: _ClassVar[int]
    ASC_FIELD_NUMBER: _ClassVar[int]
    NULLS_FIRST_FIELD_NUMBER: _ClassVar[int]
    expr: LogicalExprNode
    asc: bool
    nulls_first: bool
    def __init__(
        self, expr: _Optional[_Union[LogicalExprNode, _Mapping]] = ..., asc: bool = ..., nulls_first: bool = ...
    ) -> None: ...

class WindowFrame(_message.Message):
    __slots__ = ("window_frame_units", "start_bound", "bound")
    WINDOW_FRAME_UNITS_FIELD_NUMBER: _ClassVar[int]
    START_BOUND_FIELD_NUMBER: _ClassVar[int]
    BOUND_FIELD_NUMBER: _ClassVar[int]
    window_frame_units: WindowFrameUnits
    start_bound: WindowFrameBound
    bound: WindowFrameBound
    def __init__(
        self,
        window_frame_units: _Optional[_Union[WindowFrameUnits, str]] = ...,
        start_bound: _Optional[_Union[WindowFrameBound, _Mapping]] = ...,
        bound: _Optional[_Union[WindowFrameBound, _Mapping]] = ...,
    ) -> None: ...

class WindowFrameBound(_message.Message):
    __slots__ = ("window_frame_bound_type", "bound_value")
    WINDOW_FRAME_BOUND_TYPE_FIELD_NUMBER: _ClassVar[int]
    BOUND_VALUE_FIELD_NUMBER: _ClassVar[int]
    window_frame_bound_type: WindowFrameBoundType
    bound_value: _arrow_pb2.ScalarValue
    def __init__(
        self,
        window_frame_bound_type: _Optional[_Union[WindowFrameBoundType, str]] = ...,
        bound_value: _Optional[_Union[_arrow_pb2.ScalarValue, _Mapping]] = ...,
    ) -> None: ...



from chalk._gen.chalk.artifacts.v1 import export_pb2 as _export_pb2
from chalk._gen.chalk.auth.v1 import audit_pb2 as _audit_pb2
from chalk._gen.chalk.auth.v1 import permissions_pb2 as _permissions_pb2
from chalk._gen.chalk.common.v1 import chalk_error_pb2 as _chalk_error_pb2
from chalk._gen.chalk.graph.v1 import graph_pb2 as _graph_pb2
from chalk._gen.chalk.server.v1 import deployment_pb2 as _deployment_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class DeployBranchRequest(_message.Message):
    __slots__ = ("branch_name", "reset_branch", "archive", "is_hot_deploy")
    BRANCH_NAME_FIELD_NUMBER: _ClassVar[int]
    RESET_BRANCH_FIELD_NUMBER: _ClassVar[int]
    ARCHIVE_FIELD_NUMBER: _ClassVar[int]
    IS_HOT_DEPLOY_FIELD_NUMBER: _ClassVar[int]
    branch_name: str
    reset_branch: bool
    archive: bytes
    is_hot_deploy: bool
    def __init__(
        self,
        branch_name: _Optional[str] = ...,
        reset_branch: bool = ...,
        archive: _Optional[bytes] = ...,
        is_hot_deploy: bool = ...,
    ) -> None: ...

class DeployBranchResponse(_message.Message):
    __slots__ = ("deployment_id", "graph", "deployment_errors", "export")
    DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    GRAPH_FIELD_NUMBER: _ClassVar[int]
    DEPLOYMENT_ERRORS_FIELD_NUMBER: _ClassVar[int]
    EXPORT_FIELD_NUMBER: _ClassVar[int]
    deployment_id: str
    graph: _graph_pb2.Graph
    deployment_errors: _containers.RepeatedCompositeFieldContainer[_chalk_error_pb2.ChalkError]
    export: _export_pb2.Export
    def __init__(
        self,
        deployment_id: _Optional[str] = ...,
        graph: _Optional[_Union[_graph_pb2.Graph, _Mapping]] = ...,
        deployment_errors: _Optional[_Iterable[_Union[_chalk_error_pb2.ChalkError, _Mapping]]] = ...,
        export: _Optional[_Union[_export_pb2.Export, _Mapping]] = ...,
    ) -> None: ...

class CreateBranchFromSourceDeploymentRequest(_message.Message):
    __slots__ = ("branch_name", "source_branch_name", "source_deployment_id", "current_mainline_deployment")
    BRANCH_NAME_FIELD_NUMBER: _ClassVar[int]
    SOURCE_BRANCH_NAME_FIELD_NUMBER: _ClassVar[int]
    SOURCE_DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    CURRENT_MAINLINE_DEPLOYMENT_FIELD_NUMBER: _ClassVar[int]
    branch_name: str
    source_branch_name: str
    source_deployment_id: str
    current_mainline_deployment: _empty_pb2.Empty
    def __init__(
        self,
        branch_name: _Optional[str] = ...,
        source_branch_name: _Optional[str] = ...,
        source_deployment_id: _Optional[str] = ...,
        current_mainline_deployment: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ...,
    ) -> None: ...

class CreateBranchFromSourceDeploymentResponse(_message.Message):
    __slots__ = ("deployment_id", "deployment_errors", "export", "branch_already_exists")
    DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    DEPLOYMENT_ERRORS_FIELD_NUMBER: _ClassVar[int]
    EXPORT_FIELD_NUMBER: _ClassVar[int]
    BRANCH_ALREADY_EXISTS_FIELD_NUMBER: _ClassVar[int]
    deployment_id: str
    deployment_errors: _containers.RepeatedCompositeFieldContainer[_chalk_error_pb2.ChalkError]
    export: _export_pb2.Export
    branch_already_exists: bool
    def __init__(
        self,
        deployment_id: _Optional[str] = ...,
        deployment_errors: _Optional[_Iterable[_Union[_chalk_error_pb2.ChalkError, _Mapping]]] = ...,
        export: _Optional[_Union[_export_pb2.Export, _Mapping]] = ...,
        branch_already_exists: bool = ...,
    ) -> None: ...

class GetDeploymentRequest(_message.Message):
    __slots__ = ("deployment_id",)
    DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    deployment_id: str
    def __init__(self, deployment_id: _Optional[str] = ...) -> None: ...

class GetDeploymentResponse(_message.Message):
    __slots__ = ("deployment",)
    DEPLOYMENT_FIELD_NUMBER: _ClassVar[int]
    deployment: _deployment_pb2.Deployment
    def __init__(self, deployment: _Optional[_Union[_deployment_pb2.Deployment, _Mapping]] = ...) -> None: ...

class ListDeploymentsRequest(_message.Message):
    __slots__ = ("cursor", "limit", "include_branch", "branch_name")
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_BRANCH_FIELD_NUMBER: _ClassVar[int]
    BRANCH_NAME_FIELD_NUMBER: _ClassVar[int]
    cursor: str
    limit: int
    include_branch: bool
    branch_name: str
    def __init__(
        self,
        cursor: _Optional[str] = ...,
        limit: _Optional[int] = ...,
        include_branch: bool = ...,
        branch_name: _Optional[str] = ...,
    ) -> None: ...

class ListDeploymentsResponse(_message.Message):
    __slots__ = ("deployments", "cursor")
    DEPLOYMENTS_FIELD_NUMBER: _ClassVar[int]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    deployments: _containers.RepeatedCompositeFieldContainer[_deployment_pb2.Deployment]
    cursor: str
    def __init__(
        self,
        deployments: _Optional[_Iterable[_Union[_deployment_pb2.Deployment, _Mapping]]] = ...,
        cursor: _Optional[str] = ...,
    ) -> None: ...

class SuspendDeploymentRequest(_message.Message):
    __slots__ = ("deployment_id",)
    DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    deployment_id: str
    def __init__(self, deployment_id: _Optional[str] = ...) -> None: ...

class SuspendDeploymentResponse(_message.Message):
    __slots__ = ("deployment",)
    DEPLOYMENT_FIELD_NUMBER: _ClassVar[int]
    deployment: _deployment_pb2.Deployment
    def __init__(self, deployment: _Optional[_Union[_deployment_pb2.Deployment, _Mapping]] = ...) -> None: ...

class ScaleDeploymentRequest(_message.Message):
    __slots__ = ("deployment_id", "sizing")
    DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    SIZING_FIELD_NUMBER: _ClassVar[int]
    deployment_id: str
    sizing: _deployment_pb2.InstanceSizing
    def __init__(
        self,
        deployment_id: _Optional[str] = ...,
        sizing: _Optional[_Union[_deployment_pb2.InstanceSizing, _Mapping]] = ...,
    ) -> None: ...

class ScaleDeploymentResponse(_message.Message):
    __slots__ = ("deployment",)
    DEPLOYMENT_FIELD_NUMBER: _ClassVar[int]
    deployment: _deployment_pb2.Deployment
    def __init__(self, deployment: _Optional[_Union[_deployment_pb2.Deployment, _Mapping]] = ...) -> None: ...

class TagDeploymentRequest(_message.Message):
    __slots__ = ("deployment_id", "tag", "mirror_weight")
    DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    TAG_FIELD_NUMBER: _ClassVar[int]
    MIRROR_WEIGHT_FIELD_NUMBER: _ClassVar[int]
    deployment_id: str
    tag: str
    mirror_weight: int
    def __init__(
        self, deployment_id: _Optional[str] = ..., tag: _Optional[str] = ..., mirror_weight: _Optional[int] = ...
    ) -> None: ...

class TagDeploymentResponse(_message.Message):
    __slots__ = ("deployment", "untagged_deployment_id")
    DEPLOYMENT_FIELD_NUMBER: _ClassVar[int]
    UNTAGGED_DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    deployment: _deployment_pb2.Deployment
    untagged_deployment_id: str
    def __init__(
        self,
        deployment: _Optional[_Union[_deployment_pb2.Deployment, _Mapping]] = ...,
        untagged_deployment_id: _Optional[str] = ...,
    ) -> None: ...

class GetActiveDeploymentsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetActiveDeploymentsResponse(_message.Message):
    __slots__ = ("deployments",)
    DEPLOYMENTS_FIELD_NUMBER: _ClassVar[int]
    deployments: _containers.RepeatedCompositeFieldContainer[_deployment_pb2.Deployment]
    def __init__(
        self, deployments: _Optional[_Iterable[_Union[_deployment_pb2.Deployment, _Mapping]]] = ...
    ) -> None: ...



from __future__ import annotations

from typing import TYPE_CHECKING, Optional, Sequence, Type

import numpy as np
import pyarrow as pa

from chalk.features._embedding.embedding_provider import EmbeddingProvider
from chalk.features._embedding.utils import ModelSpecs
from chalk.features._vector import Vector
from chalk.utils.missing_dependency import missing_dependency_exception

if TYPE_CHECKING:
    import cohere
else:
    cohere = None

_MODEL_SPECS = {
    "embed-english-v3.0": ModelSpecs(
        default_dimensions=1024,
        validate_dimensions=lambda dim: dim == 1024,
        validation_message="Must be 1024.",
        requires_none_input=True,
    ),
    "embed-multilingual-v3.0": ModelSpecs(
        default_dimensions=1024,
        validate_dimensions=lambda dim: dim == 1024,
        validation_message="Must be 1024.",
        requires_none_input=True,
    ),
    "embed-english-light-v3.0": ModelSpecs(
        default_dimensions=384,
        validate_dimensions=lambda dim: dim == 384,
        validation_message="Must be 384.",
        requires_none_input=True,
    ),
    "embed-multilingual-light-v3.0": ModelSpecs(
        default_dimensions=384,
        validate_dimensions=lambda dim: dim == 384,
        validation_message="Must be 384.",
        requires_none_input=True,
    ),
}


class CohereProvider(EmbeddingProvider):
    def __init__(self, model: str, dimensions: Optional[int] = None) -> None:
        super().__init__()
        try:
            global cohere
            import cohere
        except ImportError:
            raise missing_dependency_exception("chalkpy[cohere]")

        if model not in _MODEL_SPECS:
            supported_models_str = ", ".join(f"'{model}'" for model in _MODEL_SPECS)
            raise ValueError(
                f"Unsupported model '{model}' for Cohere. The supported models are [{supported_models_str}]."
            )
        specs = _MODEL_SPECS[model]
        if dimensions is not None and not specs.validate_dimensions(dimensions):
            raise ValueError(f"Unsupported dimensions '{dimensions}' for model '{model}'. {specs.validation_message}")
        self.model = model
        self.dimensions = dimensions if dimensions is not None else specs.default_dimensions

    def get_provider_name(self) -> str:
        return "Cohere"

    def get_model_name(self) -> str:
        return self.model

    def validate_input_schema(self, input_schema: Sequence[pa.DataType]) -> str | None:
        # Cohere requires two columns -- the data and the input type
        # For now not validating but will do so later
        return

    async def async_generate_embedding(self, input: pa.Table):
        co = cohere.AsyncClient()
        text_input: list[str] = input.column(0).to_pylist()
        response = await co.embed(texts=text_input, model=self.model, input_type="search_document")
        vectors = np.array(
            response.embeddings, dtype=np.dtype(self.get_vector_class().precision.replace("fp", "float"))
        )
        yield pa.FixedSizeListArray.from_arrays(vectors.reshape(-1), self.dimensions)

    def generate_embedding(self, input: pa.Table) -> pa.FixedSizeListArray:
        co = cohere.Client()
        text_input: list[str] = input.column(0).to_pylist()
        response = co.embed(texts=text_input, model=self.model, input_type="search_document")
        vectors = np.array(
            response.embeddings, dtype=np.dtype(self.get_vector_class().precision.replace("fp", "float"))
        )
        return pa.FixedSizeListArray.from_arrays(vectors.reshape(-1), self.dimensions)

    def get_vector_class(self) -> Type[Vector]:
        return Vector[self.dimensions]



from chalk._gen.chalk.utils.v1 import sensitive_pb2 as _sensitive_pb2
from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LinkSessionStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    LINK_SESSION_STATUS_UNSPECIFIED: _ClassVar[LinkSessionStatus]
    LINK_SESSION_STATUS_PENDING: _ClassVar[LinkSessionStatus]
    LINK_SESSION_STATUS_SUCCESS: _ClassVar[LinkSessionStatus]
    LINK_SESSION_STATUS_FAILED: _ClassVar[LinkSessionStatus]
    LINK_SESSION_STATUS_NOT_FOUND: _ClassVar[LinkSessionStatus]
    LINK_SESSION_STATUS_FORBIDDEN: _ClassVar[LinkSessionStatus]

LINK_SESSION_STATUS_UNSPECIFIED: LinkSessionStatus
LINK_SESSION_STATUS_PENDING: LinkSessionStatus
LINK_SESSION_STATUS_SUCCESS: LinkSessionStatus
LINK_SESSION_STATUS_FAILED: LinkSessionStatus
LINK_SESSION_STATUS_NOT_FOUND: LinkSessionStatus
LINK_SESSION_STATUS_FORBIDDEN: LinkSessionStatus

class LinkToken(_message.Message):
    __slots__ = ("name", "client_id", "client_secret", "api_server", "active_environment", "valid_until")
    NAME_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_SECRET_FIELD_NUMBER: _ClassVar[int]
    API_SERVER_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    VALID_UNTIL_FIELD_NUMBER: _ClassVar[int]
    name: str
    client_id: str
    client_secret: str
    api_server: str
    active_environment: str
    valid_until: _timestamp_pb2.Timestamp
    def __init__(
        self,
        name: _Optional[str] = ...,
        client_id: _Optional[str] = ...,
        client_secret: _Optional[str] = ...,
        api_server: _Optional[str] = ...,
        active_environment: _Optional[str] = ...,
        valid_until: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
    ) -> None: ...

class GetLinkSessionRequest(_message.Message):
    __slots__ = ("link_code", "project_name")
    LINK_CODE_FIELD_NUMBER: _ClassVar[int]
    PROJECT_NAME_FIELD_NUMBER: _ClassVar[int]
    link_code: str
    project_name: str
    def __init__(self, link_code: _Optional[str] = ..., project_name: _Optional[str] = ...) -> None: ...

class GetLinkSessionResponse(_message.Message):
    __slots__ = ("status", "message", "token", "session_id")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    status: LinkSessionStatus
    message: str
    token: LinkToken
    session_id: str
    def __init__(
        self,
        status: _Optional[_Union[LinkSessionStatus, str]] = ...,
        message: _Optional[str] = ...,
        token: _Optional[_Union[LinkToken, _Mapping]] = ...,
        session_id: _Optional[str] = ...,
    ) -> None: ...

class CreateLinkSessionRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CreateLinkSessionResponse(_message.Message):
    __slots__ = ("link_code", "auth_link", "expires_at", "session_id")
    LINK_CODE_FIELD_NUMBER: _ClassVar[int]
    AUTH_LINK_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    link_code: str
    auth_link: str
    expires_at: _timestamp_pb2.Timestamp
    session_id: str
    def __init__(
        self,
        link_code: _Optional[str] = ...,
        auth_link: _Optional[str] = ...,
        expires_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        session_id: _Optional[str] = ...,
    ) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chalk/server/v1/team.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from chalk._gen.chalk.auth.v1 import agent_pb2 as chalk_dot_auth_dot_v1_dot_agent__pb2
from chalk._gen.chalk.auth.v1 import audit_pb2 as chalk_dot_auth_dot_v1_dot_audit__pb2
from chalk._gen.chalk.auth.v1 import displayagent_pb2 as chalk_dot_auth_dot_v1_dot_displayagent__pb2
from chalk._gen.chalk.auth.v1 import featurepermission_pb2 as chalk_dot_auth_dot_v1_dot_featurepermission__pb2
from chalk._gen.chalk.auth.v1 import permissions_pb2 as chalk_dot_auth_dot_v1_dot_permissions__pb2
from chalk._gen.chalk.server.v1 import environment_pb2 as chalk_dot_server_dot_v1_dot_environment__pb2
from chalk._gen.chalk.utils.v1 import sensitive_pb2 as chalk_dot_utils_dot_v1_dot_sensitive__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1a\x63halk/server/v1/team.proto\x12\x0f\x63halk.server.v1\x1a\x19\x63halk/auth/v1/agent.proto\x1a\x19\x63halk/auth/v1/audit.proto\x1a chalk/auth/v1/displayagent.proto\x1a%chalk/auth/v1/featurepermission.proto\x1a\x1f\x63halk/auth/v1/permissions.proto\x1a!chalk/server/v1/environment.proto\x1a\x1e\x63halk/utils/v1/sensitive.proto\x1a google/protobuf/descriptor.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\x0f\n\rGetEnvRequest"P\n\x0eGetEnvResponse\x12>\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32\x1c.chalk.server.v1.EnvironmentR\x0b\x65nvironment"2\n\x16GetEnvironmentsRequest\x12\x18\n\x07project\x18\x01 \x01(\tR\x07project"[\n\x17GetEnvironmentsResponse\x12@\n\x0c\x65nvironments\x18\x02 \x03(\x0b\x32\x1c.chalk.server.v1.EnvironmentR\x0c\x65nvironments"\x11\n\x0fGetAgentRequest">\n\x10GetAgentResponse\x12*\n\x05\x61gent\x18\x01 \x01(\x0b\x32\x14.chalk.auth.v1.AgentR\x05\x61gent"\x18\n\x16GetDisplayAgentRequest"L\n\x17GetDisplayAgentResponse\x12\x31\n\x05\x61gent\x18\x01 \x01(\x0b\x32\x1b.chalk.auth.v1.DisplayAgentR\x05\x61gent"\x82\x03\n\x04Team\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x03 \x01(\tR\x04slug\x12\x17\n\x04logo\x18\x04 \x01(\tH\x00R\x04logo\x88\x01\x01\x12\x34\n\x08projects\x18\x05 \x03(\x0b\x32\x18.chalk.server.v1.ProjectR\x08projects\x12(\n\rscim_provider\x18\x06 \x01(\tH\x01R\x0cscimProvider\x88\x01\x01\x12S\n\x10spec_config_json\x18\x07 \x03(\x0b\x32).chalk.server.v1.Team.SpecConfigJsonEntryR\x0especConfigJson\x1aY\n\x13SpecConfigJsonEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\x42\x07\n\x05_logoB\x10\n\x0e_scim_provider"\xb5\x01\n\x07Project\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07team_id\x18\x02 \x01(\tR\x06teamId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12@\n\x0c\x65nvironments\x18\x04 \x03(\x0b\x32\x1c.chalk.server.v1.EnvironmentR\x0c\x65nvironments\x12\x1e\n\x08git_repo\x18\x05 \x01(\tH\x00R\x07gitRepo\x88\x01\x01\x42\x0b\n\t_git_repo"]\n\x11\x43reateTeamRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\x17\n\x04logo\x18\x03 \x01(\tH\x00R\x04logo\x88\x01\x01\x42\x07\n\x05_logo"?\n\x12\x43reateTeamResponse\x12)\n\x04team\x18\x01 \x01(\x0b\x32\x15.chalk.server.v1.TeamR\x04team"*\n\x14\x43reateProjectRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name"K\n\x15\x43reateProjectResponse\x12\x32\n\x07project\x18\x01 \x01(\x0b\x32\x18.chalk.server.v1.ProjectR\x07project"l\n\x18\x43reateEnvironmentRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1d\n\nis_default\x18\x03 \x01(\x08R\tisDefault"[\n\x19\x43reateEnvironmentResponse\x12>\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32\x1c.chalk.server.v1.EnvironmentR\x0b\x65nvironment"\xf9\x02\n\x1aUpdateEnvironmentOperation\x12/\n\x11specs_config_json\x18\x01 \x01(\tH\x00R\x0fspecsConfigJson\x88\x01\x01\x12r\n\x13\x61\x64\x64itional_env_vars\x18\x02 \x03(\x0b\x32\x42.chalk.server.v1.UpdateEnvironmentOperation.AdditionalEnvVarsEntryR\x11\x61\x64\x64itionalEnvVars\x12=\n\x18private_pip_repositories\x18\x03 \x01(\tH\x01R\x16privatePipRepositories\x88\x01\x01\x1a\x44\n\x16\x41\x64\x64itionalEnvVarsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x14\n\x12_specs_config_jsonB\x1b\n\x19_private_pip_repositories"\xac\x01\n\x18UpdateEnvironmentRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x43\n\x06update\x18\x02 \x01(\x0b\x32+.chalk.server.v1.UpdateEnvironmentOperationR\x06update\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask"[\n\x19UpdateEnvironmentResponse\x12>\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32\x1c.chalk.server.v1.EnvironmentR\x0b\x65nvironment"\x10\n\x0eGetTeamRequest"<\n\x0fGetTeamResponse\x12)\n\x04team\x18\x01 \x01(\x0b\x32\x15.chalk.server.v1.TeamR\x04team"\xcb\x03\n\x19\x43reateServiceTokenRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12;\n\x0bpermissions\x18\x02 \x03(\x0e\x32\x19.chalk.auth.v1.PermissionR\x0bpermissions\x12\'\n\rcustom_claims\x18\x03 \x03(\tB\x02\x18\x01R\x0c\x63ustomClaims\x12\x43\n\x0f\x63ustomer_claims\x18\x04 \x03(\x0b\x32\x1a.chalk.auth.v1.CustomClaimR\x0e\x63ustomerClaims\x12\x81\x01\n\x19\x66\x65\x61ture_tag_to_permission\x18\x05 \x03(\x0b\x32\x46.chalk.server.v1.CreateServiceTokenRequest.FeatureTagToPermissionEntryR\x16\x66\x65\x61tureTagToPermission\x1ak\n\x1b\x46\x65\x61tureTagToPermissionEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x36\n\x05value\x18\x02 \x01(\x0e\x32 .chalk.auth.v1.FeaturePermissionR\x05value:\x02\x38\x01"\x7f\n\x1a\x43reateServiceTokenResponse\x12\x36\n\x05\x61gent\x18\x01 \x01(\x0b\x32 .chalk.auth.v1.ServiceTokenAgentR\x05\x61gent\x12)\n\rclient_secret\x18\x02 \x01(\tB\x04\xd8\xa1\'\x01R\x0c\x63lientSecret"+\n\x19\x44\x65leteServiceTokenRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id"\x1c\n\x1a\x44\x65leteServiceTokenResponse"\xd7\x01\n\x15PermissionDescription\x12)\n\x02id\x18\x01 \x01(\x0e\x32\x19.chalk.auth.v1.PermissionR\x02id\x12\x12\n\x04slug\x18\x02 \x01(\tR\x04slug\x12\x1c\n\tnamespace\x18\x03 \x01(\tR\tnamespace\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription\x12+\n\x11group_description\x18\x06 \x01(\tR\x10groupDescription"\x87\x02\n\x0fRoleDescription\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12;\n\x0bpermissions\x18\x04 \x03(\x0e\x32\x19.chalk.auth.v1.PermissionR\x0bpermissions\x12R\n\x13\x66\x65\x61ture_permissions\x18\x05 \x01(\x0b\x32!.chalk.auth.v1.FeaturePermissionsR\x12\x66\x65\x61turePermissions\x12\x1d\n\nis_default\x18\x06 \x01(\x08R\tisDefault" \n\x1eGetAvailablePermissionsRequest"\x8d\x02\n\x1fGetAvailablePermissionsResponse\x12H\n\x0bpermissions\x18\x01 \x03(\x0b\x32&.chalk.server.v1.PermissionDescriptionR\x0bpermissions\x12\x36\n\x05roles\x18\x02 \x03(\x0b\x32 .chalk.server.v1.RoleDescriptionR\x05roles\x12h\n#available_service_token_permissions\x18\x03 \x03(\x0e\x32\x19.chalk.auth.v1.PermissionR availableServiceTokenPermissions"z\n\x1fUpsertFeaturePermissionsRequest\x12\x12\n\x04role\x18\x01 \x01(\tR\x04role\x12\x43\n\x0bpermissions\x18\x02 \x01(\x0b\x32!.chalk.auth.v1.FeaturePermissionsR\x0bpermissions"{\n UpsertFeaturePermissionsResponse\x12\x12\n\x04role\x18\x01 \x01(\tR\x04role\x12\x43\n\x0bpermissions\x18\x02 \x01(\x0b\x32!.chalk.auth.v1.FeaturePermissionsR\x0bpermissions"\x1a\n\x18ListServiceTokensRequest"\\\n\x19ListServiceTokensResponse\x12?\n\x06\x61gents\x18\x01 \x03(\x0b\x32\'.chalk.auth.v1.DisplayServiceTokenAgentR\x06\x61gents"\xbf\x03\n\x19UpdateServiceTokenRequest\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12;\n\x0bpermissions\x18\x03 \x03(\x0e\x32\x19.chalk.auth.v1.PermissionR\x0bpermissions\x12\x43\n\x0f\x63ustomer_claims\x18\x04 \x03(\x0b\x32\x1a.chalk.auth.v1.CustomClaimR\x0e\x63ustomerClaims\x12\x81\x01\n\x19\x66\x65\x61ture_tag_to_permission\x18\x05 \x03(\x0b\x32\x46.chalk.server.v1.UpdateServiceTokenRequest.FeatureTagToPermissionEntryR\x16\x66\x65\x61tureTagToPermission\x1ak\n\x1b\x46\x65\x61tureTagToPermissionEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x36\n\x05value\x18\x02 \x01(\x0e\x32 .chalk.auth.v1.FeaturePermissionR\x05value:\x02\x38\x01"[\n\x1aUpdateServiceTokenResponse\x12=\n\x05\x61gent\x18\x01 \x01(\x0b\x32\'.chalk.auth.v1.DisplayServiceTokenAgentR\x05\x61gent"U\n\x1eUpdateScimGroupSettingsRequest\x12\x1d\n\nquery_tags\x18\x01 \x03(\tR\tqueryTags\x12\x14\n\x05group\x18\x02 \x01(\tR\x05group"@\n\x1fUpdateScimGroupSettingsResponse\x12\x1d\n\nquery_tags\x18\x01 \x03(\tR\tqueryTags"Y\n\x17InviteTeamMemberRequest\x12\x14\n\x05\x65mail\x18\x01 \x01(\tR\x05\x65mail\x12\x1c\n\x07role_id\x18\x02 \x01(\tH\x00R\x06roleId\x88\x01\x01\x42\n\n\x08_role_id"\x1a\n\x18InviteTeamMemberResponse")\n\x17\x45xpireTeamInviteRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id"\x1a\n\x18\x45xpireTeamInviteResponse"\xa3\x01\n\nTeamInvite\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05\x65mail\x18\x02 \x01(\tR\x05\x65mail\x12\x12\n\x04team\x18\x03 \x01(\tR\x04team\x12\x17\n\x04role\x18\x04 \x01(\tH\x00R\x04role\x88\x01\x01\x12\x39\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAtB\x07\n\x05_role"\x18\n\x16ListTeamInvitesRequest"P\n\x17ListTeamInvitesResponse\x12\x35\n\x07invites\x18\x01 \x03(\x0b\x32\x1b.chalk.server.v1.TeamInviteR\x07invites"h\n\tScimGroup\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x18\n\x07\x64isplay\x18\x02 \x01(\tR\x07\x64isplay\x12\x17\n\x07team_id\x18\x03 \x01(\tR\x06teamId\x12\x18\n\x07members\x18\x04 \x03(\tR\x07members"\x93\x01\n\x17ScimGroupRoleAssignment\x12\x19\n\x08group_id\x18\x01 \x01(\tR\x07groupId\x12%\n\x0e\x65nvironment_id\x18\x03 \x01(\tR\renvironmentId\x12\x17\n\x07role_id\x18\x04 \x01(\tR\x06roleId\x12\x1d\n\nquery_tags\x18\x05 \x03(\tR\tqueryTags"A\n\x12UserRoleAssignment\x12\x17\n\x07role_id\x18\x01 \x01(\tR\x06roleId\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type"\xdb\x01\n\x0fUserPermissions\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12%\n\x0e\x65nvironment_id\x18\x02 \x01(\tR\renvironmentId\x12\x42\n\nuser_roles\x18\x03 \x03(\x0b\x32#.chalk.server.v1.UserRoleAssignmentR\tuserRoles\x12\x44\n\x10user_permissions\x18\x04 \x03(\x0e\x32\x19.chalk.auth.v1.PermissionR\x0fuserPermissions"\x87\x02\n\x04User\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x04name\x18\x02 \x01(\tH\x00R\x04name\x88\x01\x01\x12\x19\n\x05\x65mail\x18\x03 \x01(\tH\x01R\x05\x65mail\x88\x01\x01\x12\x19\n\x05image\x18\x04 \x01(\tH\x02R\x05image\x88\x01\x01\x12\x1c\n\x07team_id\x18\x05 \x01(\tH\x03R\x06teamId\x88\x01\x01\x12\x46\n\x0e\x64\x65\x61\x63tivated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x04R\rdeactivatedAt\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_emailB\x08\n\x06_imageB\n\n\x08_team_idB\x11\n\x0f_deactivated_at"\xd5\x01\n\x16\x45nvironmentPermissions\x12%\n\x0e\x65nvironment_id\x18\x01 \x01(\tR\renvironmentId\x12G\n\nscim_roles\x18\x02 \x03(\x0b\x32(.chalk.server.v1.ScimGroupRoleAssignmentR\tscimRoles\x12K\n\x10user_permissions\x18\x03 \x03(\x0b\x32 .chalk.server.v1.UserPermissionsR\x0fuserPermissions"\x1b\n\x19GetTeamPermissionsRequest"\xad\x02\n\x1aGetTeamPermissionsResponse\x12\x36\n\x05roles\x18\x01 \x03(\x0b\x32 .chalk.server.v1.RoleDescriptionR\x05roles\x12;\n\x0bscim_groups\x18\x02 \x03(\x0b\x32\x1a.chalk.server.v1.ScimGroupR\nscimGroups\x12`\n\x17\x65nvironment_permissions\x18\x03 \x03(\x0b\x32\'.chalk.server.v1.EnvironmentPermissionsR\x16\x65nvironmentPermissions\x12\x38\n\x0cteam_members\x18\x04 \x03(\x0b\x32\x15.chalk.server.v1.UserR\x0bteamMembers2\x82\x12\n\x0bTeamService\x12Q\n\x06GetEnv\x12\x1e.chalk.server.v1.GetEnvRequest\x1a\x1f.chalk.server.v1.GetEnvResponse"\x06\x90\x02\x01\x80}\x0b\x12l\n\x0fGetEnvironments\x12\'.chalk.server.v1.GetEnvironmentsRequest\x1a(.chalk.server.v1.GetEnvironmentsResponse"\x06\x90\x02\x01\x80}\x02\x12W\n\x08GetAgent\x12 .chalk.server.v1.GetAgentRequest\x1a!.chalk.server.v1.GetAgentResponse"\x06\x90\x02\x01\x80}\x02\x12l\n\x0fGetDisplayAgent\x12\'.chalk.server.v1.GetDisplayAgentRequest\x1a(.chalk.server.v1.GetDisplayAgentResponse"\x06\x90\x02\x01\x80}\x02\x12T\n\x07GetTeam\x12\x1f.chalk.server.v1.GetTeamRequest\x1a .chalk.server.v1.GetTeamResponse"\x06\x90\x02\x01\x80}\x02\x12`\n\nCreateTeam\x12".chalk.server.v1.CreateTeamRequest\x1a#.chalk.server.v1.CreateTeamResponse"\t\x80}\x1b\x8a\xd3\x0e\x02\x08\x02\x12i\n\rCreateProject\x12%.chalk.server.v1.CreateProjectRequest\x1a&.chalk.server.v1.CreateProjectResponse"\t\x80}\x1a\x8a\xd3\x0e\x02\x08\x02\x12u\n\x11\x43reateEnvironment\x12).chalk.server.v1.CreateEnvironmentRequest\x1a*.chalk.server.v1.CreateEnvironmentResponse"\t\x80}\x1a\x8a\xd3\x0e\x02\x08\x02\x12u\n\x11UpdateEnvironment\x12).chalk.server.v1.UpdateEnvironmentRequest\x1a*.chalk.server.v1.UpdateEnvironmentResponse"\t\x80}\x0c\x8a\xd3\x0e\x02\x08\x02\x12\x84\x01\n\x17GetAvailablePermissions\x12/.chalk.server.v1.GetAvailablePermissionsRequest\x1a\x30.chalk.server.v1.GetAvailablePermissionsResponse"\x06\x90\x02\x01\x80}\x02\x12\x8f\x01\n\x12\x43reateServiceToken\x12*.chalk.server.v1.CreateServiceTokenRequest\x1a+.chalk.server.v1.CreateServiceTokenResponse" \x80}\x15\x8a\xd3\x0e\x19\x08\x02\x12\x15\x43reated service token\x12x\n\x12\x44\x65leteServiceToken\x12*.chalk.server.v1.DeleteServiceTokenRequest\x1a+.chalk.server.v1.DeleteServiceTokenResponse"\t\x80}\x15\x8a\xd3\x0e\x02\x08\x02\x12o\n\x11ListServiceTokens\x12).chalk.server.v1.ListServiceTokensRequest\x1a*.chalk.server.v1.ListServiceTokensResponse"\x03\x80}\x16\x12x\n\x12UpdateServiceToken\x12*.chalk.server.v1.UpdateServiceTokenRequest\x1a+.chalk.server.v1.UpdateServiceTokenResponse"\t\x80}\x15\x8a\xd3\x0e\x02\x08\x02\x12r\n\x10InviteTeamMember\x12(.chalk.server.v1.InviteTeamMemberRequest\x1a).chalk.server.v1.InviteTeamMemberResponse"\t\x80}\x07\x8a\xd3\x0e\x02\x08\x02\x12r\n\x10\x45xpireTeamInvite\x12(.chalk.server.v1.ExpireTeamInviteRequest\x1a).chalk.server.v1.ExpireTeamInviteResponse"\t\x80}\x08\x8a\xd3\x0e\x02\x08\x02\x12i\n\x0fListTeamInvites\x12\'.chalk.server.v1.ListTeamInvitesRequest\x1a(.chalk.server.v1.ListTeamInvitesResponse"\x03\x80}\t\x12\x8a\x01\n\x18UpsertFeaturePermissions\x12\x30.chalk.server.v1.UpsertFeaturePermissionsRequest\x1a\x31.chalk.server.v1.UpsertFeaturePermissionsResponse"\t\x80}\x15\x8a\xd3\x0e\x02\x08\x02\x12\x87\x01\n\x17UpdateScimGroupSettings\x12/.chalk.server.v1.UpdateScimGroupSettingsRequest\x1a\x30.chalk.server.v1.UpdateScimGroupSettingsResponse"\t\x80}\n\x8a\xd3\x0e\x02\x08\x02\x12r\n\x12GetTeamPermissions\x12*.chalk.server.v1.GetTeamPermissionsRequest\x1a+.chalk.server.v1.GetTeamPermissionsResponse"\x03\x80}\x02\x42\x92\x01\n\x13\x63om.chalk.server.v1B\tTeamProtoP\x01Z\x12server/v1;serverv1\xa2\x02\x03\x43SX\xaa\x02\x0f\x43halk.Server.V1\xca\x02\x0f\x43halk\\Server\\V1\xe2\x02\x1b\x43halk\\Server\\V1\\GPBMetadata\xea\x02\x11\x43halk::Server::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "chalk.server.v1.team_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\023com.chalk.server.v1B\tTeamProtoP\001Z\022server/v1;serverv1\242\002\003CSX\252\002\017Chalk.Server.V1\312\002\017Chalk\\Server\\V1\342\002\033Chalk\\Server\\V1\\GPBMetadata\352\002\021Chalk::Server::V1"
    _globals["_TEAM_SPECCONFIGJSONENTRY"]._options = None
    _globals["_TEAM_SPECCONFIGJSONENTRY"]._serialized_options = b"8\001"
    _globals["_UPDATEENVIRONMENTOPERATION_ADDITIONALENVVARSENTRY"]._options = None
    _globals["_UPDATEENVIRONMENTOPERATION_ADDITIONALENVVARSENTRY"]._serialized_options = b"8\001"
    _globals["_CREATESERVICETOKENREQUEST_FEATURETAGTOPERMISSIONENTRY"]._options = None
    _globals["_CREATESERVICETOKENREQUEST_FEATURETAGTOPERMISSIONENTRY"]._serialized_options = b"8\001"
    _globals["_CREATESERVICETOKENREQUEST"].fields_by_name["custom_claims"]._options = None
    _globals["_CREATESERVICETOKENREQUEST"].fields_by_name["custom_claims"]._serialized_options = b"\030\001"
    _globals["_CREATESERVICETOKENRESPONSE"].fields_by_name["client_secret"]._options = None
    _globals["_CREATESERVICETOKENRESPONSE"].fields_by_name["client_secret"]._serialized_options = b"\330\241'\001"
    _globals["_UPDATESERVICETOKENREQUEST_FEATURETAGTOPERMISSIONENTRY"]._options = None
    _globals["_UPDATESERVICETOKENREQUEST_FEATURETAGTOPERMISSIONENTRY"]._serialized_options = b"8\001"
    _globals["_TEAMSERVICE"].methods_by_name["GetEnv"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name["GetEnv"]._serialized_options = b"\220\002\001\200}\013"
    _globals["_TEAMSERVICE"].methods_by_name["GetEnvironments"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name["GetEnvironments"]._serialized_options = b"\220\002\001\200}\002"
    _globals["_TEAMSERVICE"].methods_by_name["GetAgent"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name["GetAgent"]._serialized_options = b"\220\002\001\200}\002"
    _globals["_TEAMSERVICE"].methods_by_name["GetDisplayAgent"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name["GetDisplayAgent"]._serialized_options = b"\220\002\001\200}\002"
    _globals["_TEAMSERVICE"].methods_by_name["GetTeam"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name["GetTeam"]._serialized_options = b"\220\002\001\200}\002"
    _globals["_TEAMSERVICE"].methods_by_name["CreateTeam"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name["CreateTeam"]._serialized_options = b"\200}\033\212\323\016\002\010\002"
    _globals["_TEAMSERVICE"].methods_by_name["CreateProject"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name["CreateProject"]._serialized_options = b"\200}\032\212\323\016\002\010\002"
    _globals["_TEAMSERVICE"].methods_by_name["CreateEnvironment"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name[
        "CreateEnvironment"
    ]._serialized_options = b"\200}\032\212\323\016\002\010\002"
    _globals["_TEAMSERVICE"].methods_by_name["UpdateEnvironment"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name[
        "UpdateEnvironment"
    ]._serialized_options = b"\200}\014\212\323\016\002\010\002"
    _globals["_TEAMSERVICE"].methods_by_name["GetAvailablePermissions"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name["GetAvailablePermissions"]._serialized_options = b"\220\002\001\200}\002"
    _globals["_TEAMSERVICE"].methods_by_name["CreateServiceToken"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name[
        "CreateServiceToken"
    ]._serialized_options = b"\200}\025\212\323\016\031\010\002\022\025Created service token"
    _globals["_TEAMSERVICE"].methods_by_name["DeleteServiceToken"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name[
        "DeleteServiceToken"
    ]._serialized_options = b"\200}\025\212\323\016\002\010\002"
    _globals["_TEAMSERVICE"].methods_by_name["ListServiceTokens"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name["ListServiceTokens"]._serialized_options = b"\200}\026"
    _globals["_TEAMSERVICE"].methods_by_name["UpdateServiceToken"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name[
        "UpdateServiceToken"
    ]._serialized_options = b"\200}\025\212\323\016\002\010\002"
    _globals["_TEAMSERVICE"].methods_by_name["InviteTeamMember"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name[
        "InviteTeamMember"
    ]._serialized_options = b"\200}\007\212\323\016\002\010\002"
    _globals["_TEAMSERVICE"].methods_by_name["ExpireTeamInvite"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name[
        "ExpireTeamInvite"
    ]._serialized_options = b"\200}\010\212\323\016\002\010\002"
    _globals["_TEAMSERVICE"].methods_by_name["ListTeamInvites"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name["ListTeamInvites"]._serialized_options = b"\200}\t"
    _globals["_TEAMSERVICE"].methods_by_name["UpsertFeaturePermissions"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name[
        "UpsertFeaturePermissions"
    ]._serialized_options = b"\200}\025\212\323\016\002\010\002"
    _globals["_TEAMSERVICE"].methods_by_name["UpdateScimGroupSettings"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name[
        "UpdateScimGroupSettings"
    ]._serialized_options = b"\200}\n\212\323\016\002\010\002"
    _globals["_TEAMSERVICE"].methods_by_name["GetTeamPermissions"]._options = None
    _globals["_TEAMSERVICE"].methods_by_name["GetTeamPermissions"]._serialized_options = b"\200}\002"
    _globals["_GETENVREQUEST"]._serialized_start = 405
    _globals["_GETENVREQUEST"]._serialized_end = 420
    _globals["_GETENVRESPONSE"]._serialized_start = 422
    _globals["_GETENVRESPONSE"]._serialized_end = 502
    _globals["_GETENVIRONMENTSREQUEST"]._serialized_start = 504
    _globals["_GETENVIRONMENTSREQUEST"]._serialized_end = 554
    _globals["_GETENVIRONMENTSRESPONSE"]._serialized_start = 556
    _globals["_GETENVIRONMENTSRESPONSE"]._serialized_end = 647
    _globals["_GETAGENTREQUEST"]._serialized_start = 649
    _globals["_GETAGENTREQUEST"]._serialized_end = 666
    _globals["_GETAGENTRESPONSE"]._serialized_start = 668
    _globals["_GETAGENTRESPONSE"]._serialized_end = 730
    _globals["_GETDISPLAYAGENTREQUEST"]._serialized_start = 732
    _globals["_GETDISPLAYAGENTREQUEST"]._serialized_end = 756
    _globals["_GETDISPLAYAGENTRESPONSE"]._serialized_start = 758
    _globals["_GETDISPLAYAGENTRESPONSE"]._serialized_end = 834
    _globals["_TEAM"]._serialized_start = 837
    _globals["_TEAM"]._serialized_end = 1223
    _globals["_TEAM_SPECCONFIGJSONENTRY"]._serialized_start = 1107
    _globals["_TEAM_SPECCONFIGJSONENTRY"]._serialized_end = 1196
    _globals["_PROJECT"]._serialized_start = 1226
    _globals["_PROJECT"]._serialized_end = 1407
    _globals["_CREATETEAMREQUEST"]._serialized_start = 1409
    _globals["_CREATETEAMREQUEST"]._serialized_end = 1502
    _globals["_CREATETEAMRESPONSE"]._serialized_start = 1504
    _globals["_CREATETEAMRESPONSE"]._serialized_end = 1567
    _globals["_CREATEPROJECTREQUEST"]._serialized_start = 1569
    _globals["_CREATEPROJECTREQUEST"]._serialized_end = 1611
    _globals["_CREATEPROJECTRESPONSE"]._serialized_start = 1613
    _globals["_CREATEPROJECTRESPONSE"]._serialized_end = 1688
    _globals["_CREATEENVIRONMENTREQUEST"]._serialized_start = 1690
    _globals["_CREATEENVIRONMENTREQUEST"]._serialized_end = 1798
    _globals["_CREATEENVIRONMENTRESPONSE"]._serialized_start = 1800
    _globals["_CREATEENVIRONMENTRESPONSE"]._serialized_end = 1891
    _globals["_UPDATEENVIRONMENTOPERATION"]._serialized_start = 1894
    _globals["_UPDATEENVIRONMENTOPERATION"]._serialized_end = 2271
    _globals["_UPDATEENVIRONMENTOPERATION_ADDITIONALENVVARSENTRY"]._serialized_start = 2152
    _globals["_UPDATEENVIRONMENTOPERATION_ADDITIONALENVVARSENTRY"]._serialized_end = 2220
    _globals["_UPDATEENVIRONMENTREQUEST"]._serialized_start = 2274
    _globals["_UPDATEENVIRONMENTREQUEST"]._serialized_end = 2446
    _globals["_UPDATEENVIRONMENTRESPONSE"]._serialized_start = 2448
    _globals["_UPDATEENVIRONMENTRESPONSE"]._serialized_end = 2539
    _globals["_GETTEAMREQUEST"]._serialized_start = 2541
    _globals["_GETTEAMREQUEST"]._serialized_end = 2557
    _globals["_GETTEAMRESPONSE"]._serialized_start = 2559
    _globals["_GETTEAMRESPONSE"]._serialized_end = 2619
    _globals["_CREATESERVICETOKENREQUEST"]._serialized_start = 2622
    _globals["_CREATESERVICETOKENREQUEST"]._serialized_end = 3081
    _globals["_CREATESERVICETOKENREQUEST_FEATURETAGTOPERMISSIONENTRY"]._serialized_start = 2974
    _globals["_CREATESERVICETOKENREQUEST_FEATURETAGTOPERMISSIONENTRY"]._serialized_end = 3081
    _globals["_CREATESERVICETOKENRESPONSE"]._serialized_start = 3083
    _globals["_CREATESERVICETOKENRESPONSE"]._serialized_end = 3210
    _globals["_DELETESERVICETOKENREQUEST"]._serialized_start = 3212
    _globals["_DELETESERVICETOKENREQUEST"]._serialized_end = 3255
    _globals["_DELETESERVICETOKENRESPONSE"]._serialized_start = 3257
    _globals["_DELETESERVICETOKENRESPONSE"]._serialized_end = 3285
    _globals["_PERMISSIONDESCRIPTION"]._serialized_start = 3288
    _globals["_PERMISSIONDESCRIPTION"]._serialized_end = 3503
    _globals["_ROLEDESCRIPTION"]._serialized_start = 3506
    _globals["_ROLEDESCRIPTION"]._serialized_end = 3769
    _globals["_GETAVAILABLEPERMISSIONSREQUEST"]._serialized_start = 3771
    _globals["_GETAVAILABLEPERMISSIONSREQUEST"]._serialized_end = 3803
    _globals["_GETAVAILABLEPERMISSIONSRESPONSE"]._serialized_start = 3806
    _globals["_GETAVAILABLEPERMISSIONSRESPONSE"]._serialized_end = 4075
    _globals["_UPSERTFEATUREPERMISSIONSREQUEST"]._serialized_start = 4077
    _globals["_UPSERTFEATUREPERMISSIONSREQUEST"]._serialized_end = 4199
    _globals["_UPSERTFEATUREPERMISSIONSRESPONSE"]._serialized_start = 4201
    _globals["_UPSERTFEATUREPERMISSIONSRESPONSE"]._serialized_end = 4324
    _globals["_LISTSERVICETOKENSREQUEST"]._serialized_start = 4326
    _globals["_LISTSERVICETOKENSREQUEST"]._serialized_end = 4352
    _globals["_LISTSERVICETOKENSRESPONSE"]._serialized_start = 4354
    _globals["_LISTSERVICETOKENSRESPONSE"]._serialized_end = 4446
    _globals["_UPDATESERVICETOKENREQUEST"]._serialized_start = 4449
    _globals["_UPDATESERVICETOKENREQUEST"]._serialized_end = 4896
    _globals["_UPDATESERVICETOKENREQUEST_FEATURETAGTOPERMISSIONENTRY"]._serialized_start = 2974
    _globals["_UPDATESERVICETOKENREQUEST_FEATURETAGTOPERMISSIONENTRY"]._serialized_end = 3081
    _globals["_UPDATESERVICETOKENRESPONSE"]._serialized_start = 4898
    _globals["_UPDATESERVICETOKENRESPONSE"]._serialized_end = 4989
    _globals["_UPDATESCIMGROUPSETTINGSREQUEST"]._serialized_start = 4991
    _globals["_UPDATESCIMGROUPSETTINGSREQUEST"]._serialized_end = 5076
    _globals["_UPDATESCIMGROUPSETTINGSRESPONSE"]._serialized_start = 5078
    _globals["_UPDATESCIMGROUPSETTINGSRESPONSE"]._serialized_end = 5142
    _globals["_INVITETEAMMEMBERREQUEST"]._serialized_start = 5144
    _globals["_INVITETEAMMEMBERREQUEST"]._serialized_end = 5233
    _globals["_INVITETEAMMEMBERRESPONSE"]._serialized_start = 5235
    _globals["_INVITETEAMMEMBERRESPONSE"]._serialized_end = 5261
    _globals["_EXPIRETEAMINVITEREQUEST"]._serialized_start = 5263
    _globals["_EXPIRETEAMINVITEREQUEST"]._serialized_end = 5304
    _globals["_EXPIRETEAMINVITERESPONSE"]._serialized_start = 5306
    _globals["_EXPIRETEAMINVITERESPONSE"]._serialized_end = 5332
    _globals["_TEAMINVITE"]._serialized_start = 5335
    _globals["_TEAMINVITE"]._serialized_end = 5498
    _globals["_LISTTEAMINVITESREQUEST"]._serialized_start = 5500
    _globals["_LISTTEAMINVITESREQUEST"]._serialized_end = 5524
    _globals["_LISTTEAMINVITESRESPONSE"]._serialized_start = 5526
    _globals["_LISTTEAMINVITESRESPONSE"]._serialized_end = 5606
    _globals["_SCIMGROUP"]._serialized_start = 5608
    _globals["_SCIMGROUP"]._serialized_end = 5712
    _globals["_SCIMGROUPROLEASSIGNMENT"]._serialized_start = 5715
    _globals["_SCIMGROUPROLEASSIGNMENT"]._serialized_end = 5862
    _globals["_USERROLEASSIGNMENT"]._serialized_start = 5864
    _globals["_USERROLEASSIGNMENT"]._serialized_end = 5929
    _globals["_USERPERMISSIONS"]._serialized_start = 5932
    _globals["_USERPERMISSIONS"]._serialized_end = 6151
    _globals["_USER"]._serialized_start = 6154
    _globals["_USER"]._serialized_end = 6417
    _globals["_ENVIRONMENTPERMISSIONS"]._serialized_start = 6420
    _globals["_ENVIRONMENTPERMISSIONS"]._serialized_end = 6633
    _globals["_GETTEAMPERMISSIONSREQUEST"]._serialized_start = 6635
    _globals["_GETTEAMPERMISSIONSREQUEST"]._serialized_end = 6662
    _globals["_GETTEAMPERMISSIONSRESPONSE"]._serialized_start = 6665
    _globals["_GETTEAMPERMISSIONSRESPONSE"]._serialized_end = 6966
    _globals["_TEAMSERVICE"]._serialized_start = 6969
    _globals["_TEAMSERVICE"]._serialized_end = 9275
# @@protoc_insertion_point(module_scope)



from typing import Optional

from chalk.operators import StaticExpression


class ColumnExpression(StaticExpression):
    _chalk__expression_name = StaticExpression._chalk__expression_prefix + "column"

    def __init__(self, source_column: str, alias: Optional[str] = None) -> None:
        super().__init__(source_column=source_column, aliased_name=alias)
        self.source_column = source_column
        self.aliased_name = alias

    def alias(self, name: str) -> StaticExpression:
        return ColumnExpression(self.source_column, alias=name)

    def final_name(self) -> str:
        return self.aliased_name or self.source_column



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chalk/nodepools/v1/karpenter.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from chalk._gen.chalk.kubernetes.v1 import nodes_pb2 as chalk_dot_kubernetes_dot_v1_dot_nodes__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n"chalk/nodepools/v1/karpenter.proto\x12\x12\x63halk.nodepools.v1\x1a\x1f\x63halk/kubernetes/v1/nodes.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xb0\x01\n!KarpenterNodepoolDisruptionBudget\x12\x14\n\x05nodes\x18\x01 \x01(\tR\x05nodes\x12\x1f\n\x08schedule\x18\x02 \x01(\tH\x00R\x08schedule\x88\x01\x01\x12:\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationH\x01R\x08\x64uration\x88\x01\x01\x42\x0b\n\t_scheduleB\x0b\n\t_duration"\xa2\x02\n\x1bKarpenterNodepoolDisruption\x12K\n\x11\x63onsolidate_after\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x10\x63onsolidateAfter\x88\x01\x01\x12\x36\n\x14\x63onsolidation_policy\x18\x02 \x01(\tH\x01R\x13\x63onsolidationPolicy\x88\x01\x01\x12O\n\x07\x62udgets\x18\x03 \x03(\x0b\x32\x35.chalk.nodepools.v1.KarpenterNodepoolDisruptionBudgetR\x07\x62udgetsB\x14\n\x12_consolidate_afterB\x17\n\x15_consolidation_policy"r\n\x15KarpenterNodeClassRef\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x17\n\x04kind\x18\x02 \x01(\tH\x00R\x04kind\x88\x01\x01\x12\x19\n\x05group\x18\x03 \x01(\tH\x01R\x05group\x88\x01\x01\x42\x07\n\x05_kindB\x08\n\x06_group"h\n KarpenterNodeSelectorRequirement\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x1a\n\x08operator\x18\x02 \x01(\tR\x08operator\x12\x16\n\x06values\x18\x03 \x03(\tR\x06values"\xa8\x04\n\x1dKarpenterNodepoolTemplateSpec\x12@\n\x06taints\x18\x01 \x03(\x0b\x32(.chalk.kubernetes.v1.KubernetesNodeTaintR\x06taints\x12O\n\x0estartup_taints\x18\x02 \x03(\x0b\x32(.chalk.kubernetes.v1.KubernetesNodeTaintR\rstartupTaints\x12X\n\x0crequirements\x18\x03 \x03(\x0b\x32\x34.chalk.nodepools.v1.KarpenterNodeSelectorRequirementR\x0crequirements\x12O\n\x0enode_class_ref\x18\x04 \x01(\x0b\x32).chalk.nodepools.v1.KarpenterNodeClassRefR\x0cnodeClassRef\x12\x41\n\x0c\x65xpire_after\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x0b\x65xpireAfter\x88\x01\x01\x12X\n\x18termination_grace_period\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationH\x01R\x16terminationGracePeriod\x88\x01\x01\x42\x0f\n\r_expire_afterB\x1b\n\x19_termination_grace_period"\xe3\x02\n!KarpenterNodepoolTemplateMetadata\x12Y\n\x06labels\x18\x01 \x03(\x0b\x32\x41.chalk.nodepools.v1.KarpenterNodepoolTemplateMetadata.LabelsEntryR\x06labels\x12h\n\x0b\x61nnotations\x18\x02 \x03(\x0b\x32\x46.chalk.nodepools.v1.KarpenterNodepoolTemplateMetadata.AnnotationsEntryR\x0b\x61nnotations\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01"\xb5\x01\n\x19KarpenterNodepoolTemplate\x12Q\n\x08metadata\x18\x01 \x01(\x0b\x32\x35.chalk.nodepools.v1.KarpenterNodepoolTemplateMetadataR\x08metadata\x12\x45\n\x04spec\x18\x02 \x01(\x0b\x32\x31.chalk.nodepools.v1.KarpenterNodepoolTemplateSpecR\x04spec"\xe5\x02\n\x15KarpenterNodepoolSpec\x12O\n\ndisruption\x18\x01 \x01(\x0b\x32/.chalk.nodepools.v1.KarpenterNodepoolDisruptionR\ndisruption\x12I\n\x08template\x18\x02 \x01(\x0b\x32-.chalk.nodepools.v1.KarpenterNodepoolTemplateR\x08template\x12M\n\x06limits\x18\x03 \x03(\x0b\x32\x35.chalk.nodepools.v1.KarpenterNodepoolSpec.LimitsEntryR\x06limits\x12\x1b\n\x06weight\x18\x04 \x01(\x05H\x00R\x06weight\x88\x01\x01\x1a\x39\n\x0bLimitsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\t\n\x07_weight"\x87\x04\n\x19KarpenterNodepoolMetadata\x12`\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32>.chalk.nodepools.v1.KarpenterNodepoolMetadata.AnnotationsEntryR\x0b\x61nnotations\x12I\n\x12\x63reation_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11\x63reationTimestamp\x12\x1e\n\ngeneration\x18\x03 \x01(\x03R\ngeneration\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12)\n\x10resource_version\x18\x05 \x01(\tR\x0fresourceVersion\x12\x10\n\x03uid\x18\x06 \x01(\tR\x03uid\x12Q\n\x06labels\x18\x07 \x03(\x0b\x32\x39.chalk.nodepools.v1.KarpenterNodepoolMetadata.LabelsEntryR\x06labels\x1a>\n\x10\x41nnotationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01"\xcd\x01\n\x1aKarpenterNodepoolCondition\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12\x16\n\x06status\x18\x02 \x01(\tR\x06status\x12\x30\n\x14last_transition_time\x18\x04 \x01(\x03R\x12lastTransitionTime\x12\x1b\n\x06reason\x18\x05 \x01(\tH\x00R\x06reason\x88\x01\x01\x12\x1d\n\x07message\x18\x06 \x01(\tH\x01R\x07message\x88\x01\x01\x42\t\n\x07_reasonB\n\n\x08_message"\x81\x02\n\x17KarpenterNodepoolStatus\x12X\n\tresources\x18\x01 \x03(\x0b\x32:.chalk.nodepools.v1.KarpenterNodepoolStatus.ResourcesEntryR\tresources\x12N\n\nconditions\x18\x02 \x03(\x0b\x32..chalk.nodepools.v1.KarpenterNodepoolConditionR\nconditions\x1a<\n\x0eResourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01"\x97\x02\n\x11KarpenterNodepool\x12\x1f\n\x0b\x61pi_version\x18\x01 \x01(\tR\napiVersion\x12\x12\n\x04kind\x18\x02 \x01(\tR\x04kind\x12I\n\x08metadata\x18\x03 \x01(\x0b\x32-.chalk.nodepools.v1.KarpenterNodepoolMetadataR\x08metadata\x12=\n\x04spec\x18\x04 \x01(\x0b\x32).chalk.nodepools.v1.KarpenterNodepoolSpecR\x04spec\x12\x43\n\x06status\x18\x05 \x01(\x0b\x32+.chalk.nodepools.v1.KarpenterNodepoolStatusR\x06statusB\xac\x01\n\x16\x63om.chalk.nodepools.v1B\x0eKarpenterProtoP\x01Z\x18nodepools/v1;nodepoolsv1\xa2\x02\x03\x43NX\xaa\x02\x12\x43halk.Nodepools.V1\xca\x02\x12\x43halk\\Nodepools\\V1\xe2\x02\x1e\x43halk\\Nodepools\\V1\\GPBMetadata\xea\x02\x14\x43halk::Nodepools::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "chalk.nodepools.v1.karpenter_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\026com.chalk.nodepools.v1B\016KarpenterProtoP\001Z\030nodepools/v1;nodepoolsv1\242\002\003CNX\252\002\022Chalk.Nodepools.V1\312\002\022Chalk\\Nodepools\\V1\342\002\036Chalk\\Nodepools\\V1\\GPBMetadata\352\002\024Chalk::Nodepools::V1"
    _globals["_KARPENTERNODEPOOLTEMPLATEMETADATA_LABELSENTRY"]._options = None
    _globals["_KARPENTERNODEPOOLTEMPLATEMETADATA_LABELSENTRY"]._serialized_options = b"8\001"
    _globals["_KARPENTERNODEPOOLTEMPLATEMETADATA_ANNOTATIONSENTRY"]._options = None
    _globals["_KARPENTERNODEPOOLTEMPLATEMETADATA_ANNOTATIONSENTRY"]._serialized_options = b"8\001"
    _globals["_KARPENTERNODEPOOLSPEC_LIMITSENTRY"]._options = None
    _globals["_KARPENTERNODEPOOLSPEC_LIMITSENTRY"]._serialized_options = b"8\001"
    _globals["_KARPENTERNODEPOOLMETADATA_ANNOTATIONSENTRY"]._options = None
    _globals["_KARPENTERNODEPOOLMETADATA_ANNOTATIONSENTRY"]._serialized_options = b"8\001"
    _globals["_KARPENTERNODEPOOLMETADATA_LABELSENTRY"]._options = None
    _globals["_KARPENTERNODEPOOLMETADATA_LABELSENTRY"]._serialized_options = b"8\001"
    _globals["_KARPENTERNODEPOOLSTATUS_RESOURCESENTRY"]._options = None
    _globals["_KARPENTERNODEPOOLSTATUS_RESOURCESENTRY"]._serialized_options = b"8\001"
    _globals["_KARPENTERNODEPOOLDISRUPTIONBUDGET"]._serialized_start = 157
    _globals["_KARPENTERNODEPOOLDISRUPTIONBUDGET"]._serialized_end = 333
    _globals["_KARPENTERNODEPOOLDISRUPTION"]._serialized_start = 336
    _globals["_KARPENTERNODEPOOLDISRUPTION"]._serialized_end = 626
    _globals["_KARPENTERNODECLASSREF"]._serialized_start = 628
    _globals["_KARPENTERNODECLASSREF"]._serialized_end = 742
    _globals["_KARPENTERNODESELECTORREQUIREMENT"]._serialized_start = 744
    _globals["_KARPENTERNODESELECTORREQUIREMENT"]._serialized_end = 848
    _globals["_KARPENTERNODEPOOLTEMPLATESPEC"]._serialized_start = 851
    _globals["_KARPENTERNODEPOOLTEMPLATESPEC"]._serialized_end = 1403
    _globals["_KARPENTERNODEPOOLTEMPLATEMETADATA"]._serialized_start = 1406
    _globals["_KARPENTERNODEPOOLTEMPLATEMETADATA"]._serialized_end = 1761
    _globals["_KARPENTERNODEPOOLTEMPLATEMETADATA_LABELSENTRY"]._serialized_start = 1640
    _globals["_KARPENTERNODEPOOLTEMPLATEMETADATA_LABELSENTRY"]._serialized_end = 1697
    _globals["_KARPENTERNODEPOOLTEMPLATEMETADATA_ANNOTATIONSENTRY"]._serialized_start = 1699
    _globals["_KARPENTERNODEPOOLTEMPLATEMETADATA_ANNOTATIONSENTRY"]._serialized_end = 1761
    _globals["_KARPENTERNODEPOOLTEMPLATE"]._serialized_start = 1764
    _globals["_KARPENTERNODEPOOLTEMPLATE"]._serialized_end = 1945
    _globals["_KARPENTERNODEPOOLSPEC"]._serialized_start = 1948
    _globals["_KARPENTERNODEPOOLSPEC"]._serialized_end = 2305
    _globals["_KARPENTERNODEPOOLSPEC_LIMITSENTRY"]._serialized_start = 2237
    _globals["_KARPENTERNODEPOOLSPEC_LIMITSENTRY"]._serialized_end = 2294
    _globals["_KARPENTERNODEPOOLMETADATA"]._serialized_start = 2308
    _globals["_KARPENTERNODEPOOLMETADATA"]._serialized_end = 2827
    _globals["_KARPENTERNODEPOOLMETADATA_ANNOTATIONSENTRY"]._serialized_start = 1699
    _globals["_KARPENTERNODEPOOLMETADATA_ANNOTATIONSENTRY"]._serialized_end = 1761
    _globals["_KARPENTERNODEPOOLMETADATA_LABELSENTRY"]._serialized_start = 1640
    _globals["_KARPENTERNODEPOOLMETADATA_LABELSENTRY"]._serialized_end = 1697
    _globals["_KARPENTERNODEPOOLCONDITION"]._serialized_start = 2830
    _globals["_KARPENTERNODEPOOLCONDITION"]._serialized_end = 3035
    _globals["_KARPENTERNODEPOOLSTATUS"]._serialized_start = 3038
    _globals["_KARPENTERNODEPOOLSTATUS"]._serialized_end = 3295
    _globals["_KARPENTERNODEPOOLSTATUS_RESOURCESENTRY"]._serialized_start = 3235
    _globals["_KARPENTERNODEPOOLSTATUS_RESOURCESENTRY"]._serialized_end = 3295
    _globals["_KARPENTERNODEPOOL"]._serialized_start = 3298
    _globals["_KARPENTERNODEPOOL"]._serialized_end = 3577
# @@protoc_insertion_point(module_scope)
